%macro fcf_iem_load_alerts(ds=);

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002ST * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    FSK_ALERT - &db_kc_libname..FSK_ALERT A5DG55RP.BH00019G * 
 * Target Table:    Extract - work.W1NGESW2               A5DG55RP.BR0001TU * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1NGESW2;
quit;

proc sql;
   create view work.W1NGESW2 as
      select
         ALERT_ID   
            format = 11.
            informat = 11.
            label = 'alert_id',
         ALERT_TYPE_CD as INCIDENT_TYPE_CD length = 32   
            format = $32.
            informat = $32.
            label = 'INCIDENT_TYPE_CD',
         ALERT_CATEGORY_CD as INCIDENT_CATEGORY_CD length = 32   
            format = $32.
            informat = $32.
            label = 'INCIDENT_CATEGORY_CD',
         ALERT_SUBCATEGORY_CD as INCIDENT_SUBCATEGORY_CD length = 32   
            format = $32.
            informat = $32.
            label = 'INCIDENT_SUBCATEGORY_CD',
         MONEY_LAUNDERING_RISK_SCORE,
         TERROR_FINANCING_RISK_SCORE,
         ALERT_DESCRIPTION,
         PRIMARY_ENTITY_NUMBER,
         PRIMARY_ENTITY_NAME,
         SCENARIO_ID,
         SCENARIO_NAME,
         ACTUAL_VALUES_TEXT,
         CREATE_DATE,
         ALERT_STATUS_CODE
   from &SOURCEDS
      where LOGICAL_DELETE_IND = "N" & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1NGESW2;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002SU * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Extract - work.W1NGESW2               A5DG55RP.BR0001TU * 
 * Target Table:    New Incidents - iem.new_incidents     A5DG55RP.BH0001AS * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1NGESW2); 

   data _null_;
      call symput('current_dt',put(datetime(),datetime22.));
   run;

   /*---- Map the columns  ----*/ 
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W2OM9SJY;
   quit;
   
   proc sql;
      create view work.W2OM9SJY as
         select
            . as INCIDENT_RK length = 8
               format = 11.
               informat = 11.,
            ("&current_dt"dt) as VALID_FROM_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            . as VALID_TO_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            . as CASE_RK length = 8
               format = 11.
               informat = 11.,
            (CATX('-','ALT',compress(put(ALERT_ID,32.)))) as INCIDENT_ID length = 50
               format = $50.
               informat = $50.,
            ("&segKCschema") as SOURCE_SYSTEM_CD length = 10
               format = $10.
               informat = $10.,
            INCIDENT_TYPE_CD,
            INCIDENT_CATEGORY_CD,
            INCIDENT_SUBCATEGORY_CD,
            "" as INCIDENT_DESC length = 100
               format = $100.
               informat = $100.,
            . as INCIDENT_FROM_DT length = 8
               format = DATETIME20.
               informat = DATETIME20.,
            "" as INCIDENT_FROM_TM length = 8
               format = $8.
               informat = $8.,
            . as INCIDENT_TO_DT length = 8
               format = DATETIME20.
               informat = DATETIME20.,
            "" as INCIDENT_TO_TM length = 8
               format = $8.
               informat = $8.,
            . as DETECTION_DT length = 8
               format = DATETIME20.
               informat = DATETIME20.,
            "" as DETECTION_TM length = 8
               format = $8.
               informat = $8.,
            . as NOTIFICATION_DT length = 8
               format = DATETIME20.
               informat = DATETIME20.,
            "" as NOTIFICATION_TM length = 8
               format = $8.
               informat = $8.,
            "" as UI_DEF_FILE_NM length = 100
               format = $100.
               informat = $100.,
            ("&ecm_user") as CREATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            ("&current_dt"dt) as CREATE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            ("&ecm_user") as UPDATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            (1) as VERSION_NO length = 8
               format = 11.
               informat = 11.,
            ("0") as DELETE_FLG length = 1
               format = $1.
               informat = $1.,
            "" as INVESTIGATOR_USER_ID length = 60
               format = $60.
               informat = $60.,
            ("ACT") as INCIDENT_DISPOSITION_CD length = 10
               format = $10.
               informat = $10.,
            . as CLOSE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            "" as INCIDENT_STATUS_CD length = 10
               format = $10.
               informat = $10.,
            MONEY_LAUNDERING_RISK_SCORE,
            TERROR_FINANCING_RISK_SCORE,
            ALERT_DESCRIPTION,
            SCENARIO_ID,
            SCENARIO_NAME,
            ACTUAL_VALUES_TEXT,
            . as RISK_CLASSIFICATION length = 8
               format = 2.
               informat = 2.,
            . as PROPOSED_RISK_CLASSIFICATION length = 8
               format = 2.
               informat = 2.,
            CREATE_DATE,
            PRIMARY_ENTITY_NAME as PARTY_NAME,
            PRIMARY_ENTITY_NUMBER as PARTY_NUMBER,
            ALERT_STATUS_CODE
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W2OM9SJY;

   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_incidents;
   quit;
      
   data iem.new_incidents;
      attrib INCIDENT_RK length = 8
         format = 11.
         informat = 11.
         label = 'INCIDENT_RK'; 
      attrib VALID_FROM_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM'; 
      attrib VALID_TO_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_TO_DTTM'; 
      attrib CASE_RK length = 8
         format = 11.
         informat = 11.
         label = 'CASE_RK'; 
      attrib INCIDENT_ID length = $50
         format = $50.
         informat = $50.
         label = 'INCIDENT_ID'; 
      attrib SOURCE_SYSTEM_CD length = $10
         format = $10.
         informat = $10.
         label = 'SOURCE_SYSTEM_CD'; 
      attrib INCIDENT_TYPE_CD length = $32
         format = $32.
         informat = $32.
         label = 'INCIDENT_TYPE_CD'; 
      attrib INCIDENT_CATEGORY_CD length = $32
         format = $32.
         informat = $32.
         label = 'INCIDENT_CATEGORY_CD'; 
      attrib INCIDENT_SUBCATEGORY_CD length = $32
         format = $32.
         informat = $32.
         label = 'INCIDENT_SUBCATEGORY_CD'; 
      attrib INCIDENT_DESC length = $100
         format = $100.
         informat = $100.
         label = 'INCIDENT_DESC'; 
      attrib INCIDENT_FROM_DT length = 8
         format = DATETIME20.
         informat = DATETIME20.
         label = 'INCIDENT_FROM_DT'; 
      attrib INCIDENT_FROM_TM length = $8
         format = $8.
         informat = $8.
         label = 'INCIDENT_FROM_TM'; 
      attrib INCIDENT_TO_DT length = 8
         format = DATETIME20.
         informat = DATETIME20.
         label = 'INCIDENT_TO_DT'; 
      attrib INCIDENT_TO_TM length = $8
         format = $8.
         informat = $8.
         label = 'INCIDENT_TO_TM'; 
      attrib DETECTION_DT length = 8
         format = DATETIME20.
         informat = DATETIME20.
         label = 'DETECTION_DT'; 
      attrib DETECTION_TM length = $8
         format = $8.
         informat = $8.
         label = 'DETECTION_TM'; 
      attrib NOTIFICATION_DT length = 8
         format = DATETIME20.
         informat = DATETIME20.
         label = 'NOTIFICATION_DT'; 
      attrib NOTIFICATION_TM length = $8
         format = $8.
         informat = $8.
         label = 'NOTIFICATION_TM'; 
      attrib UI_DEF_FILE_NM length = $100
         format = $100.
         informat = $100.
         label = 'UI_DEF_FILE_NM'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib UPDATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'UPDATE_USER_ID'; 
      attrib VERSION_NO length = 8
         format = 11.
         informat = 11.
         label = 'VERSION_NO'; 
      attrib DELETE_FLG length = $1
         format = $1.
         informat = $1.
         label = 'DELETE_FLG'; 
      attrib INVESTIGATOR_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'INVESTIGATOR_USER_ID'; 
      attrib INCIDENT_DISPOSITION_CD length = $10
         format = $10.
         informat = $10.
         label = 'INCIDENT_DISPOSITION_CD'; 
      attrib CLOSE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CLOSE_DTTM'; 
      attrib INCIDENT_STATUS_CD length = $10
         format = $10.
         informat = $10.
         label = 'INCIDENT_STATUS_CD'; 
      attrib MONEY_LAUNDERING_RISK_SCORE length = 8
         format = 4.
         informat = 4.
         label = 'MONEY_LAUNDERING_RISK_SCORE'; 
      attrib TERROR_FINANCING_RISK_SCORE length = 8
         format = 4.
         informat = 4.
         label = 'TERROR_FINANCING_RISK_SCORE'; 
      attrib ALERT_DESCRIPTION length = $100
         format = $100.
         informat = $100.
         label = 'ALERT_DESCRIPTION'; 
      attrib SCENARIO_ID length = 8
         format = 13.
         informat = 13.
         label = 'SCENARIO_ID'; 
      attrib SCENARIO_NAME length = $35
         format = $35.
         informat = $35.
         label = 'SCENARIO_NAME'; 
      attrib ACTUAL_VALUES_TEXT length = $255
         format = $255.
         informat = $255.
         label = 'ACTUAL_VALUES_TEXT'; 
      attrib RISK_CLASSIFICATION length = 8
         format = 2.
         informat = 2.
         label = 'RISK_CLASSIFICATION'; 
      attrib PROPOSED_RISK_CLASSIFICATION length = 8
         format = 2.
         informat = 2.
         label = 'PROPOSED_RISK_CLASSIFICATION'; 
      attrib CREATE_DATE length = 8
         format = DATETIME20.
         informat = DATETIME20.
         label = 'CREATE_DATE'; 
      attrib PARTY_NAME length = $35
         format = $35.
         informat = $35.
         label = 'PARTY_NAME'; 
      attrib PARTY_NUMBER length = $50
         format = $50.
         informat = $50.
         label = 'PARTY_NUMBER'; 
      attrib ALERT_STATUS_CODE length = $3
         format = $3.
         informat = $3.
         label = 'ALERT_STATUS_CODE'; 
      call missing(of _all_);
      stop;
   run;
      
proc append base = iem.new_incidents 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2OM9SJY;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_incidents, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=incident);

data iem.new_incidents;
	set iem.new_incidents;
	incident_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;

/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/


/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002SV * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   New Incidents - iem.new_incidents     A5DG55RP.BH0001AS * 
 *                  INCIDENT_CONFIG -                     A5DG55RP.BH00019K * 
 *                   ecm_db.INCIDENT_CONFIG                                 * 
 * Target Table:    Lookup - work.W1O3WL8K                A5DG55RP.BR0001TV * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1O3WL8K;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W1O3WL8K
         (keep = INCIDENT_RK VALID_FROM_DTTM VALID_TO_DTTM CASE_RK INCIDENT_ID 
                 SOURCE_SYSTEM_CD INCIDENT_TYPE_CD INCIDENT_CATEGORY_CD 
                 INCIDENT_SUBCATEGORY_CD INCIDENT_DESC INCIDENT_FROM_DT 
                 INCIDENT_FROM_TM INCIDENT_TO_DT INCIDENT_TO_TM DETECTION_DT 
                 DETECTION_TM NOTIFICATION_DT NOTIFICATION_TM UI_DEF_FILE_NM 
                 CREATE_USER_ID CREATE_DTTM UPDATE_USER_ID VERSION_NO DELETE_FLG 
                 INVESTIGATOR_USER_ID INCIDENT_DISPOSITION_CD CLOSE_DTTM 
                 INCIDENT_STATUS_CD )
      ; 
   
   attrib INCIDENT_RK length=8 format=11. label="INCIDENT_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          VALID_TO_DTTM length=8 format=DATETIME27.6 label="VALID_TO_DTTM"
          CASE_RK length=8 format=11. label="CASE_RK"
          INCIDENT_ID length=$50 format=$50. label="INCIDENT_ID"
          SOURCE_SYSTEM_CD length=$10 format=$10. label="SOURCE_SYSTEM_CD"
          INCIDENT_TYPE_CD length=$32 format=$32. label="INCIDENT_TYPE_CD"
          INCIDENT_CATEGORY_CD length=$32 format=$32. label="INCIDENT_CATEGORY_CD"
          INCIDENT_SUBCATEGORY_CD length=$32 format=$32. label="INCIDENT_SUBCATEGORY_CD"
          INCIDENT_DESC length=$100 format=$100. label="INCIDENT_DESC"
          INCIDENT_FROM_DT length=8 format=DATETIME20. label="INCIDENT_FROM_DT"
          INCIDENT_FROM_TM length=$8 format=$8. label="INCIDENT_FROM_TM"
          INCIDENT_TO_DT length=8 format=DATETIME20. label="INCIDENT_TO_DT"
          INCIDENT_TO_TM length=$8 format=$8. label="INCIDENT_TO_TM"
          DETECTION_DT length=8 format=DATETIME20. label="DETECTION_DT"
          DETECTION_TM length=$8 format=$8. label="DETECTION_TM"
          NOTIFICATION_DT length=8 format=DATETIME20. label="NOTIFICATION_DT"
          NOTIFICATION_TM length=$8 format=$8. label="NOTIFICATION_TM"
          UI_DEF_FILE_NM length=$100 format=$100. label="UI_DEF_FILE_NM"
          CREATE_USER_ID length=$60 format=$60. label="CREATE_USER_ID"
          CREATE_DTTM length=8 format=DATETIME27.6 label="CREATE_DTTM"
          UPDATE_USER_ID length=$60 format=$60. label="UPDATE_USER_ID"
          VERSION_NO length=8 format=11. label="VERSION_NO"
          DELETE_FLG length=$1 format=$1. label="DELETE_FLG"
          INVESTIGATOR_USER_ID length=$60 format=$60. label="INVESTIGATOR_USER_ID"
          INCIDENT_DISPOSITION_CD length=$10 format=$10. label="INCIDENT_DISPOSITION_CD"
          CLOSE_DTTM length=8 format=DATETIME27.6 label="CLOSE_DTTM"
          INCIDENT_STATUS_CD length=$10 format=$10. label="INCIDENT_STATUS_CD"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table ecm_db.INCIDENT_CONFIG */ 
      nlobs = .; 
      dsid = open("ecm_db.INCIDENT_CONFIG"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "ecm_db.INCIDENT_CONFIG", hashexp: exponent);
            h0.defineKey( "INCIDENT_TYPE_CD",
                           "INCIDENT_CATEGORY_CD",
                           "INCIDENT_SUBCATEGORY_CD");
            h0.defineData( "UI_DEF_FILE_NM");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: ecm_db.INCIDENT_CONFIG";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " ecm_db.INCIDENT_CONFIG";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: ecm_db.INCIDENT_CONFIG";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " ecm_db.INCIDENT_CONFIG";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " ecm_db.INCIDENT_CONFIG";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " ecm_db.INCIDENT_CONFIG";
         
         abort 3; 
      end; 
      
      call missing (INCIDENT_TYPE_CD, INCIDENT_CATEGORY_CD, INCIDENT_SUBCATEGORY_CD, 
                    UI_DEF_FILE_NM); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set iem.new_incidents end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: INCIDENT_TYPE_CD, key: INCIDENT_CATEGORY_CD, key: INCIDENT_SUBCATEGORY_CD);
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W1O3WL8K; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to value  */ 
         UI_DEF_FILE_NM="aml-alert-details-01.xml";
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W1O3WL8K; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002SW * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1O3WL8K                A5DG55RP.BR0001TV * 
 * Target Table:    INCIDENT_LIVE - ecm_db.INCIDENT_LIVE  A5DG55RP.BH00019N * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1O3WL8K); 
      
   proc append base = ecm_db.INCIDENT_LIVE 
      data = &SOURCEDS  force ; 
    run; 

	/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002SX * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1O3WL8K                A5DG55RP.BR0001TV * 
 * Target Table:    INCIDENT_VERSION -                    A5DG55RP.BH00019R * 
 *                   ecm_db.INCIDENT_VERSION                                * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1O3WL8K); 

   proc append base = ecm_db.INCIDENT_VERSION 
      data = &SOURCEDS  force ; 
    run; 
   
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002SY * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1O3WL8K                A5DG55RP.BR0001TV * 
 * Target Table:    INCIDENT_X_USER_GROUP -               A5DG55RP.BH00019T * 
 *                   ecm_db.INCIDENT_X_USER_GROUP                           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1O3WL8K); 
   
   /*---- Map the columns  ----*/ 
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVX9B6;
   quit;
   
   proc sql;
      create view work.W5XVX9B6 as
         select
            INCIDENT_RK,
            ("&ecm_user_group") as USER_GROUP_NM length = 60
               format = $60.
               informat = $60.
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5XVX9B6;
   
   proc append base = ecm_db.INCIDENT_X_USER_GROUP 
      data = &SOURCEDS force ; 
    run; 
      
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVX9B6;
   quit;
   
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002SZ * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W1O3WL8K                A5DG55RP.BR0001TV * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W1O3WL8K); 

   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVX9II;
   quit;
   
   proc sql;
      create view work.W5XVX9II as
         select
            . as EVENT_RK length = 8
               format = 11.
               informat = 11.,
            ("INCIDENT") as BUSINESS_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            INCIDENT_RK as BUSINESS_OBJECT_RK,
            ("LOADEN") as EVENT_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            ("event.etl.load.txt") as EVENT_DESC length = 256
               format = $256.
               informat = $256.,
            CREATE_USER_ID,
            CREATE_DTTM,
            "" as LINKED_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            . as LINKED_OBJECT_RK length = 8
               format = 11.
               informat = 11.
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5XVX9II;
   
   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_events;
   quit;
   
   data iem.new_events;
      attrib EVENT_RK length = 8
         format = 11.
         informat = 11.
         label = 'EVENT_RK';
      attrib BUSINESS_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'BUSINESS_OBJECT_NM'; 
      attrib BUSINESS_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'BUSINESS_OBJECT_RK'; 
      attrib EVENT_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'EVENT_TYPE_CD'; 
      attrib EVENT_DESC length = $256
         format = $256.
         informat = $256.
         label = 'EVENT_DESC'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib LINKED_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'LINKED_OBJECT_NM'; 
      attrib LINKED_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'LINKED_OBJECT_RK'; 
      call missing(of _all_);
      stop;
   run;

   
proc append base = iem.new_events 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5XVX9II;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;
/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002T0 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 
      
   proc append base = ecm_db.ECM_EVENT 
      data = &SOURCEDS force ; 
    run; 
   
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVX9JB;
   quit;
   
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002T1 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Incidents - iem.new_incidents     A5DG55RP.BH0001AS * 
 * Target Table:    Extract - work.WGXJXSAL               A5DG55RP.BR0001TW * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_incidents); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete WGXJXSAL;
quit;

proc sql;
   create view work.WGXJXSAL as
      select
         INCIDENT_RK,
         VALID_FROM_DTTM,
         MONEY_LAUNDERING_RISK_SCORE as X_SASFCS_ML_RS,
         TERROR_FINANCING_RISK_SCORE as X_SASFCS_TF_RS,
         SCENARIO_ID as X_SASFCS_SCEN_ID
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.WGXJXSAL;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV0002T2 * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Extract - work.WGXJXSAL               A5DG55RP.BR0001TW * 
 * Target Table:    Alert Numeric UDF Fields -            A5DG55RP.BH0001AO * 
 *                   iem.Alert_Numeric_Udf_Fields                           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.WGXJXSAL); 

%let _INPUT = work.WGXJXSAL;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Alert_Numeric_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Alert_Numeric_Udf_Fields;
quit;

%let varColumns = X_SASFCS_ML_RS X_SASFCS_TF_RS X_SASFCS_SCEN_ID;
%let byColumns = INCIDENT_RK VALID_FROM_DTTM;

  options mprint;

  proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);

      by &byColumns;
      var &varColumns;
  run;

/**  Step end Transpose **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002T3 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Alert Numeric UDF Fields -            A5DG55RP.BH0001AO * 
 *                   iem.Alert_Numeric_Udf_Fields                           * 
 * Target Table:    INCIDENT_UDF_NUM_VALUE -              A5DG55RP.BH00019Q * 
 *                   ecm_db.INCIDENT_UDF_NUM_VALUE                          * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Alert_Numeric_Udf_Fields); 
   
   /*---- Map the columns  ----*/ 
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVXAG7;
   quit;
   
   proc sql;
      create view work.W5XVXAG7 as
         select
            INCIDENT_RK   
               format = 11.
               informat = 11.,
            VALID_FROM_DTTM,
            ('INCIDENT') as UDF_TABLE_NM length = 30
               format = $30.
               informat = $30.,
            _NAME_ as UDF_NM length = 30   
               format = $30.
               informat = $30.,
            (1) as ROW_NO length = 8
               format = 11.
               informat = 11.,
            COL1 as UDF_VALUE
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5XVXAG7;
   
   proc append base = ecm_db.INCIDENT_UDF_NUM_VALUE 
      data = &SOURCEDS force ; 
    run; 
      
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVXAG7;
   quit;
   

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002T4 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Incidents - iem.new_incidents     A5DG55RP.BH0001AS * 
 * Target Table:    Extract - work.WGYPMJ0G               A5DG55RP.BR0001TX * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_incidents); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WGYPMJ0G;
quit;

proc sql;
   create view work.WGYPMJ0G as
      select
         INCIDENT_RK,
         VALID_FROM_DTTM,
         ALERT_DESCRIPTION as X_SASFCS_ALT_DESC,
         PARTY_NUMBER as X_SASFCS_PTY_NO,
         PARTY_NAME as X_SASFCS_PTY_NM,
         SCENARIO_NAME as X_SASFCS_SCEN_NM,
         ACTUAL_VALUES_TEXT as X_SASFCS_ACT_VAL_TXT,
         ALERT_STATUS_CODE as X_SASFCS_ALT_STATUS_CD
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.WGYPMJ0G;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV0002T5 * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Extract - work.WGYPMJ0G               A5DG55RP.BR0001TX * 
 * Target Table:    Alert Character UDF Fields -          A5DG55RP.BH0001AM * 
 *                   iem.Alert_Character_Udf_Fields                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.WGYPMJ0G); 

%let _INPUT = work.WGYPMJ0G;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Alert_Character_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Alert_Character_Udf_Fields;
quit;

%let varColumns = X_SASFCS_ALT_DESC X_SASFCS_SCEN_NM X_SASFCS_PTY_NO X_SASFCS_PTY_NM 
X_SASFCS_ACT_VAL_TXT X_SASFCS_ALT_STATUS_CD;
%let byColumns = INCIDENT_RK VALID_FROM_DTTM;

options mprint;

proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);

      by &byColumns;
      var &varColumns;
  run;

/**  Step end Transpose **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002T6 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Alert Character UDF Fields -          A5DG55RP.BH0001AM * 
 *                   iem.Alert_Character_Udf_Fields                         * 
 * Target Table:    INCIDENT_UDF_CHAR_VALUE -             A5DG55RP.BH00019O * 
 *                   ecm_db.INCIDENT_UDF_CHAR_VALUE                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Alert_Character_Udf_Fields); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVXBD5;
   quit;
   
   proc sql;
      create view work.W5XVXBD5 as
         select
            INCIDENT_RK   
               informat = 11.,
            VALID_FROM_DTTM,
            ('INCIDENT') as UDF_TABLE_NM length = 30
               format = $30.
               informat = $30.,
            _NAME_ as UDF_NM length = 30   
               format = $30.
               informat = $30.,
            (1) as ROW_NO length = 8
               format = 11.
               informat = 11.,
            COL1 as UDF_VALUE length = 4000   
               format = $4000.
               informat = $4000.
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5XVXBD5;
   
   proc append base = ecm_db.INCIDENT_UDF_CHAR_VALUE 
      data = &SOURCEDS force ; 
    run; 
      
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVXBD5;
   quit;

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002T7 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Incidents - iem.new_incidents     A5DG55RP.BH0001AS * 
 * Target Table:    Extract - work.WQAQYZB                A5DG55RP.BR0001TY * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_incidents); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WQAQYZB;
quit;

proc sql;
   create view work.WQAQYZB as
      select
         INCIDENT_RK,
         VALID_FROM_DTTM,
         CREATE_DTTM as X_SASFCS_CREATE_DT
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.WQAQYZB;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV0002T8 * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Extract - work.WQAQYZB                A5DG55RP.BR0001TY * 
 * Target Table:    Alert Date UDF Fields -               A5DG55RP.BH0001AN * 
 *                   iem.Alert_Date_Udf_Fields                              * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.WQAQYZB); 

%let _INPUT = work.WQAQYZB;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Alert_Date_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Alert_Date_Udf_Fields;
quit;

%let varColumns = X_SASFCS_CREATE_DT;
%let byColumns = INCIDENT_RK VALID_FROM_DTTM;

options mprint;

  proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);

    by &byColumns;
    var &varColumns;
    
  run;

/**  Step end Transpose **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002T9 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Alert Date UDF Fields -               A5DG55RP.BH0001AN * 
 *                   iem.Alert_Date_Udf_Fields                              * 
 * Target Table:    INCIDENT_UDF_DATE_VALUE -             A5DG55RP.BH00019P * 
 *                   ecm_db.INCIDENT_UDF_DATE_VALUE                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Alert_Date_Udf_Fields); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVXCCE;
   quit;
   
   proc sql;
      create view work.W5XVXCCE as
         select
            INCIDENT_RK   
               format = 11.
               informat = 11.,
            VALID_FROM_DTTM,
            ('INCIDENT') as UDF_TABLE_NM length = 30
               format = $30.
               informat = $30.,
            _NAME_ as UDF_NM length = 30   
               format = $30.
               informat = $30.,
            (1) as ROW_NO length = 8
               format = 11.
               informat = 11.,
            COL1 as UDF_VALUE   
               format = DATETIME27.6
               informat = DATETIME27.6
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5XVXCCE;
   
   proc append base = ecm_db.INCIDENT_UDF_DATE_VALUE 
      data = &SOURCEDS force ; 
    run; 
   
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5XVXCCE;
   quit;

/**  Step end Table Loader **/

%mend;
