%macro fcf_iem_load_dimension_rels(ds_HhdPty=, ds_HhdAcc=, ds_PtyAcc=);

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RK * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    HOUSEHOLD_PARTY_NEW -                 A5DG55RP.BH0001AE * 
 *                   iem.HOUSEHOLD_PARTY_NEW                                * 
 * Target Table:    Extract - work.W1H0Z727               A5DG55RP.BR0001T8 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds_HhdPty); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H0Z727;
quit;

proc sql;
   create view work.W1H0Z727 as
      select
         party_key   
            format = 13.
            informat = 13.,
         household_key   
            format = 13.
            informat = 13.
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y"  & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1H0Z727;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002RL * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W1H0Z727               A5DG55RP.BR0001T8 * 
 *                  FSC_HOUSEHOLD_DIM -                   A5DG55RP.BH00019C * 
 *                   &db_core_libname..FSC_HOUSEHOLD_DIM                              * 
 *                  FSC_PARTY_DIM - &db_core_libname..FSC_PARTY_DIM A5DG55RP.BH00019F * 
 * Target Table:    Lookup - work.WPG8GGA2                A5DG55RP.BR0001T9 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WPG8GGA2;
quit;

DATA  work.WPG8GGA2
         (keep = HOUSEHOLD_NUMBER PARTY_NUMBER )
      ; 
   
   attrib HOUSEHOLD_NUMBER length=$50 format=$50. label="HOUSEHOLD_NUMBER"
          PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          HOUSEHOLD_KEY length= 8
          PARTY_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_HOUSEHOLD_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_HOUSEHOLD_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_HOUSEHOLD_DIM", hashexp: exponent);
            h0.defineKey( "HOUSEHOLD_KEY");
            h0.defineData( "HOUSEHOLD_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_HOUSEHOLD_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_HOUSEHOLD_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h1.defineKey( "PARTY_KEY");
            h1.defineData( "PARTY_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_PARTY_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_PARTY_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         abort 3; 
      end; 
      
      call missing (HOUSEHOLD_KEY, HOUSEHOLD_NUMBER, PARTY_KEY, PARTY_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W1H0Z727 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: household_key);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: party_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WPG8GGA2; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (HOUSEHOLD_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (PARTY_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WPG8GGA2; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RM * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    HOUSEHOLD_ACCOUNT_NEW -               A5DG55RP.BH0001AB * 
 *                   iem.HOUSEHOLD_ACCOUNT_NEW                              * 
 * Target Table:    Extract - work.W1H0ZTSA               A5DG55RP.BR0001TA * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds_HhdAcc); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H0ZTSA;
quit;

proc sql;
   create view work.W1H0ZTSA as
      select
         household_key   
            format = 13.
            informat = 13.,
         account_key   
            format = 13.
            informat = 13.
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y" & SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W1H0ZTSA;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002RN * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W1H0ZTSA               A5DG55RP.BR0001TA * 
 *                  FSC_HOUSEHOLD_DIM -                   A5DG55RP.BH00019C * 
 *                   &db_core_libname..FSC_HOUSEHOLD_DIM                              * 
 *                  FSC_ACCOUNT_DIM -                     A5DG55RP.BH000198 * 
 *                   &db_core_libname..FSC_ACCOUNT_DIM                                * 
 * Target Table:    Lookup - work.WPG8I50R                A5DG55RP.BR0001TB * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WPG8I50R;
quit;

DATA  work.WPG8I50R
         (keep = HOUSEHOLD_NUMBER ACCOUNT_NUMBER )
      ; 
   
   attrib HOUSEHOLD_NUMBER length=$50 format=$50. label="HOUSEHOLD_NUMBER"
          ACCOUNT_NUMBER length=$50 format=$50. label="ACCOUNT_NUMBER"
          HOUSEHOLD_KEY length= 8
          ACCOUNT_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_HOUSEHOLD_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_HOUSEHOLD_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_HOUSEHOLD_DIM", hashexp: exponent);
            h0.defineKey( "HOUSEHOLD_KEY");
            h0.defineData( "HOUSEHOLD_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_HOUSEHOLD_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_HOUSEHOLD_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_HOUSEHOLD_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_HOUSEHOLD_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_ACCOUNT_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_ACCOUNT_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_ACCOUNT_DIM", hashexp: exponent);
            h1.defineKey( "ACCOUNT_KEY");
            h1.defineData( "ACCOUNT_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_ACCOUNT_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_ACCOUNT_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         abort 3; 
      end; 
      
      call missing (HOUSEHOLD_KEY, HOUSEHOLD_NUMBER, ACCOUNT_KEY, ACCOUNT_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W1H0ZTSA end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: household_key);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: account_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WPG8I50R; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (HOUSEHOLD_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (ACCOUNT_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WPG8I50R; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RO * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_ACCOUNT_NEW -                   A5DG55RP.BH0001AI * 
 *                   iem.PARTY_ACCOUNT_NEW                                  * 
 * Target Table:    Extract - work.W1H10ELN               A5DG55RP.BR0001TC * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds_PtyAcc); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H10ELN;
quit;

proc sql;
   create view work.W1H10ELN as
      select
         account_key   
            format = 13.
            informat = 13.,
         party_key   
            format = 13.
            informat = 13.,
         ("PTY2ACC") as MEMBER_TYPE_CD length = 8
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y" & SEGMENT_ID = "&segKCSchema"  & ROLE_KEY ^= 1
   ;
quit;

%let SOURCEDS = work.W1H10ELN;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002RP * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W1H10ELN               A5DG55RP.BR0001TC * 
 *                  FSC_PARTY_DIM - &db_core_libname..FSC_PARTY_DIM A5DG55RP.BH00019F * 
 *                  FSC_ACCOUNT_DIM -                     A5DG55RP.BH000198 * 
 *                   &db_core_libname..FSC_ACCOUNT_DIM                                * 
 * Target Table:    Lookup - work.WPG8IV29                A5DG55RP.BR0001TD * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WPG8IV29;
quit;

DATA  work.WPG8IV29
         (keep = PARTY_NUMBER ACCOUNT_NUMBER MEMBER_TYPE_CD )
      ; 
   
   attrib PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          ACCOUNT_NUMBER length=$50 format=$50. label="ACCOUNT_NUMBER"
          MEMBER_TYPE_CD length=$8
          PARTY_KEY length= 8
          ACCOUNT_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h0.defineKey( "PARTY_KEY");
            h0.defineData( "PARTY_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_PARTY_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_PARTY_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_ACCOUNT_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_ACCOUNT_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_ACCOUNT_DIM", hashexp: exponent);
            h1.defineKey( "ACCOUNT_KEY");
            h1.defineData( "ACCOUNT_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_ACCOUNT_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_ACCOUNT_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         abort 3; 
      end; 
      
      call missing (PARTY_KEY, PARTY_NUMBER, ACCOUNT_KEY, ACCOUNT_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W1H10ELN end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: party_key);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: account_key);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WPG8IV29; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (PARTY_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (ACCOUNT_NUMBER); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.WPG8IV29; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RQ * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_ACCOUNT_NEW -                   A5DG55RP.BH0001AI * 
 *                   iem.PARTY_ACCOUNT_NEW                                  * 
 * Target Table:    Extract - work.W7UCFAZ1               A5DG55RP.BR0001TE * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds_PtyAcc); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7UCFAZ1;
quit;

proc sql;
   create view work.W7UCFAZ1 as
      select
         ACCOUNT_KEY   
            format = 13.
            informat = 13.
            label = 'ACCOUNT_KEY',
         PARTY_KEY   
            format = 13.
            informat = 13.
            label = 'PARTY_KEY',
         ("PRI2ACC") as MEMBER_TYPE_CD length = 8
   from &SOURCEDS
      where CHANGE_CURRENT_IND = "Y" & SEGMENT_ID = "&segKCSchema"  & ROLE_KEY = 1
   ;
quit;

%let SOURCEDS = work.W7UCFAZ1;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002RR * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W7UCFAZ1               A5DG55RP.BR0001TE * 
 *                  FSC_PARTY_DIM - &db_core_libname..FSC_PARTY_DIM A5DG55RP.BH00019F * 
 *                  FSC_ACCOUNT_DIM -                     A5DG55RP.BH000198 * 
 *                   &db_core_libname..FSC_ACCOUNT_DIM                                * 
 * Target Table:    Lookup - work.W7WMVFLO                A5DG55RP.BR0001TF * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7WMVFLO;
quit;

DATA  work.W7WMVFLO
         (keep = PARTY_NUMBER ACCOUNT_NUMBER MEMBER_TYPE_CD )
      ; 
   
   attrib PARTY_NUMBER length=$50 format=$50. label="PARTY_NUMBER"
          ACCOUNT_NUMBER length=$50 format=$50. label="ACCOUNT_NUMBER"
          MEMBER_TYPE_CD length=$8
          PARTY_KEY length= 8
          ACCOUNT_KEY length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table &db_core_libname..FSC_PARTY_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_PARTY_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "&db_core_libname..FSC_PARTY_DIM", hashexp: exponent);
            h0.defineKey( "PARTY_KEY");
            h0.defineData( "PARTY_NUMBER");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_PARTY_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_PARTY_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_PARTY_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_PARTY_DIM";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table &db_core_libname..FSC_ACCOUNT_DIM */ 
      nlobs = .; 
      dsid = open("&db_core_libname..FSC_ACCOUNT_DIM"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "&db_core_libname..FSC_ACCOUNT_DIM", hashexp: exponent);
            h1.defineKey( "ACCOUNT_KEY");
            h1.defineData( "ACCOUNT_NUMBER");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " &db_core_libname..FSC_ACCOUNT_DIM";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: &db_core_libname..FSC_ACCOUNT_DIM";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " &db_core_libname..FSC_ACCOUNT_DIM";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " &db_core_libname..FSC_ACCOUNT_DIM";
         
         abort 3; 
      end; 
      
      call missing (PARTY_KEY, PARTY_NUMBER, ACCOUNT_KEY, ACCOUNT_NUMBER); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W7UCFAZ1 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_KEY);
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: ACCOUNT_KEY);
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W7WMVFLO; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Skip the record  */ 
         return; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Skip the record  */ 
         return; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RS * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W1H68XOB               A5DG55RP.BR0001TG * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H68XOB;
quit;

proc sql;
   create view work.W1H68XOB as
      select
         PARTY_RK,
         (SUBSTR(PARTY_ID,5)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID'
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "HHD"
   ;
quit;

%let SOURCEDS = work.W1H68XOB;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RT * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W1H69DWS               A5DG55RP.BR0001TH * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H69DWS;
quit;

proc sql;
   create view work.W1H69DWS as
      select
         PARTY_RK,
         (SUBSTR(PARTY_ID,5)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID'
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "ACC"
   ;
quit;

%let SOURCEDS = work.W1H69DWS;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002RU * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W1H69VML               A5DG55RP.BR0001TI * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H69VML;
quit;

proc sql;
   create view work.W1H69VML as
      select
         PARTY_RK,
         (SUBSTR(PARTY_ID,5)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID'
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "PTY"
   ;
quit;

%let SOURCEDS = work.W1H69VML;
/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002VE * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WPG8GGA2                A5DG55RP.BR0001US * 
 *                  Extract - work.W1H68XOB               A5DG55RP.BR0001UZ * 
 *                  Extract - work.W1H69VML               A5DG55RP.BR0001V1 * 
 * Target Tables:   Lookup - work.W1H03BKC                A5DG55RP.BR0001V2 * 
 *                  Error Table - work.err_hhd_pty        A5DG55RP.BR0001YY * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete err_hhd_pty;
quit;

/* Creating view to eliminate column name collisions for lookup table  */ 
/*  work.W1H69VML                                                      */ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_WC7JQHNV,
      PARTY_ID
   from work.W1H69VML
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete WC7JQHNW;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.WC7JQHNW
         (keep = household_party_rk party_party_rk MEMBER_TYPE_CD )
      work.err_hhd_pty
         (keep = etls_source_row HOUSEHOLD_NUMBER PARTY_NUMBER); 
   
   attrib etls_exception_cond etls_exception_action length=$32
          etls_lookup_table length=$41
          household_party_rk length=8 format=11. label="PARTY_RK"
          party_party_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$10 format=$10. label="MEMBER_TYPE_CD"
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_WC7JQHNV length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Assign variables used for error/exception handling  */ 
   etls_source_row      = _n_;
   etls_write_to_error_table  = 0; 
   
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H68XOB */ 
      nlobs = .; 
      dsid = open("work.W1H68XOB"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H68XOB", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H68XOB";
                  missing0 = 98; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H68XOB";
            missing0 = 98; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H68XOB";
         
         missing0 = 99; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_WC7JQHNV");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview1";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview1";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview1";
         
         abort 4; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_WC7JQHNV); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WPG8GGA2 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   if (missing0 < 1) then 
   do; 
      rc0 = h0.find(key: HOUSEHOLD_NUMBER);
      household_party_rk = PARTY_RK;
   end; 
   else 
      rc0 = missing0; 
      
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: PARTY_NUMBER);
   party_party_rk = ETLS_WC7JQHNV;
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WC7JQHNW; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         if (rc0 = 99) then 
         do; 
            /* Check: Lookup table missing-Write exception row  */ 
            /* Check: Lookup table missing-Set target columns to value  */ 
         end; 
         
         else if (rc0 = 98) then 
         do; 
            /* Check: Lookup table has no rows-Write exception row  */ 
            /* Check: Lookup table has no rows-Set target columns to value  */ 
         end; 
         
         else 
         do; 
            etls_write_to_error_table = 1; 
         end; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      /* Write row to error table?  */ 
      if (etls_write_to_error_table eq 1) then 
         output work.err_hhd_pty; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H03BKC;
quit;

%put %str(NOTE: Mapping columns ...);
proc sql;
   create table work.W1H03BKC as
      select
         household_party_rk,
         party_party_rk,
         ("HHD2PTY") as MEMBER_TYPE_CD length = 10
            label = 'MEMBER_TYPE_CD'
   from work.WC7JQHNW
   ;
quit;

%let SOURCEDS = work.W1H03BKC;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WC7JQHNW;
quit;


/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002VF * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WPG8I50R                A5DG55RP.BR0001UU * 
 *                  Extract - work.W1H68XOB               A5DG55RP.BR0001UZ * 
 *                  Extract - work.W1H69DWS               A5DG55RP.BR0001V0 * 
 * Target Tables:   Lookup - work.W1H080IO                A5DG55RP.BR0001V3 * 
 *                  Error Table - work.err_hhd_acc        A5DG55RP.$0000569 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete err_hhd_acc;
quit;

/* Creating view to eliminate column name collisions for lookup table  */ 
/*  work.W1H69DWS                                                      */ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_WC6Y61IN,
      PARTY_ID
   from work.W1H69DWS
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete WC6Y61IO;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.WC6Y61IO
         (keep = household_party_rk account_party_rk MEMBER_TYPE_CD )
      work.err_hhd_acc
         (keep = etls_source_row HOUSEHOLD_NUMBER ACCOUNT_NUMBER); 
   
   attrib etls_exception_cond etls_exception_action length=$32
          etls_lookup_table length=$41
          household_party_rk length=8 format=11. label="PARTY_RK"
          account_party_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$10 format=$10. label="MEMBER_TYPE_CD"
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_WC6Y61IN length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Assign variables used for error/exception handling  */ 
   etls_source_row      = _n_;
   etls_write_to_error_table  = 0; 
   
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H68XOB */ 
      nlobs = .; 
      dsid = open("work.W1H68XOB"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H68XOB", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H68XOB";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W1H68XOB";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H68XOB";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W1H68XOB";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H68XOB";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W1H68XOB";
         
         abort 4; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_WC6Y61IN");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview1";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview1";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview1";
         
         abort 4; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_WC6Y61IN); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WPG8I50R end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: HOUSEHOLD_NUMBER);
   household_party_rk = PARTY_RK;
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: ACCOUNT_NUMBER);
   account_party_rk = ETLS_WC6Y61IN;
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.WC6Y61IO; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      /* Write row to error table?  */ 
      if (etls_write_to_error_table eq 1) then 
         output work.err_hhd_acc; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 



/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H080IO;
quit;

%put %str(NOTE: Mapping columns ...);
proc sql;
   create table work.W1H080IO as
      select
         household_party_rk,
         account_party_rk,
         ("HHD2ACC") as MEMBER_TYPE_CD length = 10
            label = 'MEMBER_TYPE_CD'
   from work.WC6Y61IO
   ;
quit;

%let SOURCEDS = work.W1H080IO;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete WC6Y61IO;
quit;

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002VG * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.WPG8IV29                A5DG55RP.BR0001UW * 
 *                  Extract - work.W1H69VML               A5DG55RP.BR0001V1 * 
 *                  Extract - work.W1H69DWS               A5DG55RP.BR0001V0 * 
 * Target Tables:   Lookup - work.W1H0CT5V                A5DG55RP.BR0001V4 * 
 *                  Error Table - work.err_pri_acc        A5DG55RP.$0000586 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete err_pri_acc;
quit;

/* Creating view to eliminate column name collisions for lookup table  */ 
/*  work.W1H69DWS                                                      */ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_WC6YIS0H,
      PARTY_ID
   from work.W1H69DWS
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W1H0CT5V;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W1H0CT5V
         (keep = party_party_rk account_party_rk MEMBER_TYPE_CD )
      work.err_pri_acc
         (keep = etls_source_row PARTY_NUMBER ACCOUNT_NUMBER MEMBER_TYPE_CD); 
   
   attrib etls_exception_cond etls_exception_action length=$32
          etls_lookup_table length=$41
          party_party_rk length=8 format=11. label="PARTY_RK"
          account_party_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$8
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_WC6YIS0H length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Assign variables used for error/exception handling  */ 
   etls_source_row      = _n_;
   etls_write_to_error_table  = 0; 
   
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H69VML */ 
      nlobs = .; 
      dsid = open("work.W1H69VML"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H69VML", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H69VML";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W1H69VML";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H69VML";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W1H69VML";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H69VML";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W1H69VML";
         
         abort 4; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_WC6YIS0H");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview1";
                  
                  abort 4; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview1";
            
            abort 4; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview1";
         
         abort 4; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_WC6YIS0H); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.WPG8IV29 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_NUMBER);
   party_party_rk = PARTY_RK;
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: ACCOUNT_NUMBER);
   account_party_rk = ETLS_WC6YIS0H;
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W1H0CT5V; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      /* Write row to error table?  */ 
      if (etls_write_to_error_table eq 1) then 
         output work.err_pri_acc; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002VH * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W7WMVFLO                A5DG55RP.BR0001UY * 
 *                  Extract - work.W1H69VML               A5DG55RP.BR0001V1 * 
 *                  Extract - work.W1H69DWS               A5DG55RP.BR0001V0 * 
 * Target Tables:   Lookup - work.W7WNW0X3                A5DG55RP.BR0001V5 * 
 *                  Error Table - work.err_pty_acc        A5DG55RP.$0000595 * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete err_pty_acc;
quit;

/* Creating view to eliminate column name collisions for lookup table  */ 
/*  work.W1H69DWS                                                      */ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete etls_temp_lookupview1;
quit;

proc sql; create view etls_temp_lookupview1 as 
   select 
      PARTY_RK as ETLS_WC6YUIDL,
      PARTY_ID
   from work.W1H69DWS
   ;
quit;
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7WNW0X3;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W7WNW0X3
         (keep = party_party_rk account_rk MEMBER_TYPE_CD )
      work.err_pty_acc
         (keep = etls_source_row PARTY_NUMBER ACCOUNT_NUMBER MEMBER_TYPE_CD); 
   
   attrib etls_exception_cond etls_exception_action length=$32
          etls_lookup_table length=$41
          party_party_rk length=8 format=11. label="PARTY_RK"
          account_rk length=8 format=11. label="PARTY_RK"
          MEMBER_TYPE_CD length=$8
          PARTY_RK length= 8
          PARTY_ID length= $50
          ETLS_WC6YUIDL length= 8
          ; 
   
   retain missing0-missing1 0; 
   
   etls_assign_target_value = 0; 
   /* Assign variables used for error/exception handling  */ 
   etls_source_row      = _n_;
   etls_write_to_error_table  = 0; 
   
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W1H69VML */ 
      nlobs = .; 
      dsid = open("work.W1H69VML"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W1H69VML", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W1H69VML";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W1H69VML";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W1H69VML";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W1H69VML";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W1H69VML";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W1H69VML";
         
         abort 3; 
      end; 
      
      /* Build hash h1 from lookup table etls_temp_lookupview1 */ 
      nlobs = .; 
      dsid = open("etls_temp_lookupview1"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h1(dataset: "etls_temp_lookupview1", hashexp: exponent);
            h1.defineKey( "PARTY_ID");
            h1.defineData( "ETLS_WC6YUIDL");
            h1.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h1.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: etls_temp_lookupview1";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " etls_temp_lookupview1";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: etls_temp_lookupview1";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " etls_temp_lookupview1";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " etls_temp_lookupview1";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " etls_temp_lookupview1";
         
         abort 3; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, ETLS_WC6YUIDL); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W7WMVFLO end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_NUMBER);
   party_party_rk = PARTY_RK;
   /* Is the current key value stored in hash h1?  */ 
   rc1 = h1.find(key: ACCOUNT_NUMBER);
   account_rk = ETLS_WC6YUIDL;
   /* Examine success of lookups  */ 
   if ( rc0=0 and rc1=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W7WNW0X3; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      if (rc1 ^= 0) then 
      do; 
         exception_total + 1; 
         etls_write_to_error_table = 1; 
      end; 
      
      /* Write row to error table?  */ 
      if (etls_write_to_error_table eq 1) then 
         output work.err_pty_acc; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 


/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV0002RZ * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W1H03BKC                A5DG55RP.BR0001TJ * 
 *                  Lookup - work.W1H080IO                A5DG55RP.BR0001TK * 
 *                  Lookup - work.W1H0CT5V                A5DG55RP.BR0001TL * 
 *                  Lookup - work.W7WNW0X3                A5DG55RP.BR0001TM * 
 * Target Table:    Append - work.W494Z1RQ                A5DG55RP.BR0001TN * 
 *==========================================================================*/ 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YDU1TI;
quit;

proc sql;
   create view work.W5YDU1TI as
      select
         household_party_rk as SOURCE_PARTY_RK,
         party_party_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD
   from work.W1H03BKC
   ;
quit;


/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YDU1TL;
quit;

proc sql;
   create view work.W5YDU1TL as
      select
         household_party_rk as SOURCE_PARTY_RK,
         account_party_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD
   from work.W1H080IO
   ;
quit;


/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YDU1TN;
quit;

proc sql;
   create view work.W5YDU1TN as
      select
         party_party_rk as SOURCE_PARTY_RK,
         account_party_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD length = 10   
            format = $10.
            informat = $10.
            label = 'MEMBER_TYPE_CD'
   from work.W1H0CT5V
   ;
quit;


/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YDU1TQ;
quit;

proc sql;
   create view work.W5YDU1TQ as
      select
         party_party_rk as SOURCE_PARTY_RK,
         account_rk as TARGET_PARTY_RK,
         MEMBER_TYPE_CD length = 10   
            format = $10.
            informat = $10.
            label = 'MEMBER_TYPE_CD'
   from work.W7WNW0X3
   ;
quit;


proc datasets lib = work nolist nowarn memtype = (data view);
   delete W494Z1RQ;
quit;

data work.W494Z1RQ / view=work.W494Z1RQ;
   set work.W5YDU1TI
       work.W5YDU1TL
       work.W5YDU1TN
       work.W5YDU1TQ;
   keep SOURCE_PARTY_RK TARGET_PARTY_RK MEMBER_TYPE_CD; 
run;

/**  Step end Append **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002S0 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W494Z1RQ                A5DG55RP.BR0001TN * 
 * Target Table:    New Party X Parties -                 A5DG55RP.BH0001AV * 
 *                   iem.New_Party_X_Parties                                * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W494Z1RQ); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
  delete W5YDU1U5;
quit;

proc sql;
  create view work.W5YDU1U5 as
     select
        SOURCE_PARTY_RK as PARTY_RK,
        TARGET_PARTY_RK as MEMBER_PARTY_RK,
        MEMBER_TYPE_CD,
        ("") as MEMBER_DESC length = 100
           format = $100.
           informat = $100.
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = %nrquote(work.W5YDU1U5); 

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete New_Party_X_Parties;
quit;

data iem.New_Party_X_Parties;
  attrib PARTY_RK length = 8
     format = 11.
     informat = 11.
     label = 'PARTY_RK'; 
  attrib MEMBER_PARTY_RK length = 8
     format = 11.
     informat = 11.
     label = 'MEMBER_PARTY_RK'; 
  attrib MEMBER_TYPE_CD length = $10
     format = $10.
     informat = $10.
     label = 'MEMBER_TYPE_CD'; 
  attrib MEMBER_DESC length = $100
     format = $100.
     informat = $100.
     label = 'MEMBER_DESC'; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.New_Party_X_Parties 
   data = &SOURCEDS force; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YDU1U5;
quit;

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002S2 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Party X Parties -                 A5DG55RP.BH0001AV * 
 *                   iem.New_Party_X_Parties                                * 
 * Target Table:    PARTY_X_PARTY - ecm_db.PARTY_X_PARTY  A5DG55RP.BH0001A0 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.New_Party_X_Parties); 

   proc append base = ecm_db.PARTY_X_PARTY 
      data = &SOURCEDS force; 
    run; 
   
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002S1 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W494Z1RQ                A5DG55RP.BR0001TN * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W494Z1RQ); 

   data _null_;
      call symput('current_dt',put(datetime(),datetime22.));
   run;

   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5YDU22T;
   quit;
   
   proc sql;
      create view work.W5YDU22T as
         select
            . as EVENT_RK length = 8
               format = 11.
               informat = 11.,
            ("PARTY") as BUSINESS_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            SOURCE_PARTY_RK as BUSINESS_OBJECT_RK,
            ("ADDPAR") as EVENT_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            MEMBER_TYPE_CD as EVENT_DESC length = 256   
               format = $256.
               informat = $256.,
            ("&ecm_user") as CREATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            ("&current_dt"dt) as CREATE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            ("PARTY") as LINKED_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            TARGET_PARTY_RK as LINKED_OBJECT_RK
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5YDU22T;
   
   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_events;
   quit;

   data iem.new_events;
      attrib EVENT_RK length = 8
         format = 11.
         informat = 11.
         label = 'EVENT_RK';
      attrib BUSINESS_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'BUSINESS_OBJECT_NM';
      attrib BUSINESS_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'BUSINESS_OBJECT_RK'; 
      attrib EVENT_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'EVENT_TYPE_CD'; 
      attrib EVENT_DESC length = $256
         format = $256.
         informat = $256.
         label = 'EVENT_DESC'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib LINKED_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'LINKED_OBJECT_NM'; 
      attrib LINKED_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'LINKED_OBJECT_RK'; 
      call missing(of _all_);
      stop;
   run;

proc append base = iem.new_events 
   data = &SOURCEDS force; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YDU22T;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;
/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002S3 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 

   proc append base = ecm_db.ECM_EVENT 
      data = &SOURCEDS force; 
    run; 

/**  Step end Table Loader **/

%mend;
