%macro fcf_iem_load_risk_rels(ds=);

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002Z6 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    NEW_RISK_ASSESSMENTS -                A5DG55RP.BH0001B7 * 
 *                   iem.NEW_RISK_ASSESSMENTS                               * 
 * Target Table:    Extract - work.W2NSG82S               A5DG55RP.BR0001WO * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(&ds); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2NSG82S;
quit;

proc sql;
   create view work.W2NSG82S as
      select
         (CATX('-','RAS',compress(put(RISK_ASSESSMENT_ID,32.)))) as risk_assessment_id length = 32
            format = $32.
            informat = $32.
            label = 'risk_assessment_id',
         (CATX('-','PTY',PARTY_NUMBER)) as party_number length = 50
            format = $50.
            informat = $50.
            label = 'party_number'
   from &SOURCEDS
      where SEGMENT_ID = "&segKCSchema"
   ;
quit;

%let SOURCEDS = work.W2NSG82S;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002Z7 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Extract - work.W2NQMC7B               A5DG55RP.BR0001WP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.PARTY_LIVE); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2NQMC7B;
quit;

proc sql;
   create view work.W2NQMC7B as
      select
         PARTY_RK,
         PARTY_ID
   from &SOURCEDS
      where PARTY_TYPE_CD = "FCFSUB"  & PARTY_CATEGORY_CD = "PTY"
   ;
quit;

%let SOURCEDS = work.W2NQMC7B;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002Z8 * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W2NSG82S               A5DG55RP.BR0001WO * 
 *                  Extract - work.W2NQMC7B               A5DG55RP.BR0001WP * 
 * Target Table:    Lookup - work.W2YT2996                A5DG55RP.BR0001WQ * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2YT2996;
quit;

DATA  work.W2YT2996
         (keep = risk_assessment_id PARTY_RK )
      ; 
   
   attrib risk_assessment_id length=$32 format=$32. label="risk_assessment_id"
          PARTY_RK length=8 format=11. label="PARTY_RK"
          PARTY_ID length= $50
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W2NQMC7B */ 
      nlobs = .; 
      dsid = open("work.W2NQMC7B"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W2NQMC7B", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W2NQMC7B";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W2NQMC7B";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W2NQMC7B";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W2NQMC7B";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W2NQMC7B";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W2NQMC7B";
         
         abort 3; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W2NSG82S end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: party_number);
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W2YT2996; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (PARTY_RK); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W2YT2996; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002Z9 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    INCIDENT_LIVE - ecm_db.INCIDENT_LIVE  A5DG55RP.BH00019N * 
 * Target Table:    Extract - work.W2NPPPX2               A5DG55RP.BR0001WR * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(ecm_db.INCIDENT_LIVE); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2NPPPX2;
quit;

proc sql;
   create view work.W2NPPPX2 as
      select
         INCIDENT_RK,
         INCIDENT_ID
   from &SOURCEDS
      where INCIDENT_TYPE_CD = "AMLRISK"
   ;
quit;

%let SOURCEDS = work.W2NPPPX2;

/**  Step end Extract **/

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002ZA * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2YT2996                A5DG55RP.BR0001WQ * 
 *                  Extract - work.W2NPPPX2               A5DG55RP.BR0001WR * 
 * Target Table:    Lookup - work.W2YVSZ9K                A5DG55RP.BR0001WS * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2YVSZ9K;
quit;

DATA  work.W2YVSZ9K
         (keep = PARTY_RK INCIDENT_RK )
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          INCIDENT_RK length=8 format=11. label="INCIDENT_RK"
          INCIDENT_ID length= $50
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table work.W2NPPPX2 */ 
      nlobs = .; 
      dsid = open("work.W2NPPPX2"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "work.W2NPPPX2", hashexp: exponent);
            h0.defineKey( "INCIDENT_ID");
            h0.defineData( "INCIDENT_RK");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: work.W2NPPPX2";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " work.W2NPPPX2";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: work.W2NPPPX2";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " work.W2NPPPX2";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened: work.W2NPPPX2";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " work.W2NPPPX2";
         
         abort 3; 
      end; 
      
      call missing (INCIDENT_ID, INCIDENT_RK); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W2YT2996 end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: risk_assessment_id);
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W2YVSZ9K; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Set target columns to missing  */ 
         call missing (INCIDENT_RK); 
         etls_assign_target_value = 1; 
      end; 
      
      /* Set target columns to value/missing requested?  */ 
      if (etls_assign_target_value eq 1) then 
         /* Write row to target  */ 
         output work.W2YVSZ9K; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002ZB * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2YVSZ9K                A5DG55RP.BR0001WS * 
 * Target Table:    New Incident X Parties -              A5DG55RP.BH0001AR * 
 *                   iem.New_Incident_X_Parties                             * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2YVSZ9K); 

   data _null_;
      call symput('current_dt',put(datetime(),datetime22.));
   run;
  

   /*---- Map the columns  ----*/ 
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5YK2X3F;
   quit;
   
   proc sql;
      create view work.W5YK2X3F as
         select
            INCIDENT_RK,
            PARTY_RK,
            ("RSK2PTY") as RELATION_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            ("") as RELATION_DESC length = 100
               format = $100.
               informat = $100.,
            ("&current_dt"dt) as CREATE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5YK2X3F;
   
   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete New_Incident_X_Parties;
   quit;
   
   data iem.New_Incident_X_Parties;
      attrib INCIDENT_RK length = 8
         format = 11.
         informat = 11.; 
      attrib PARTY_RK length = 8
         format = 11.
         informat = 11.; 
      attrib RELATION_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'RELATION_TYPE_CD'; 
      attrib RELATION_DESC length = $100
         format = $100.
         informat = $100.
         label = 'RELATION_DESC'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6; 
      call missing(of _all_);
      stop;
   run;

proc append base = iem.New_Incident_X_Parties 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YK2X3F;
quit;

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002ZC * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2YVSZ9K                A5DG55RP.BR0001WS * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2YVSZ9K); 
   
   data _null_;
      call symput('current_dt',put(datetime(),datetime22.));
   run;

   /*---- Map the columns  ----*/ 
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5YK2X44;
   quit;
   
   proc sql;
      create view work.W5YK2X44 as
         select
            . as EVENT_RK length = 8
               format = 11.
               informat = 11.,
            ("INCIDENT") as BUSINESS_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            INCIDENT_RK as BUSINESS_OBJECT_RK,
            ("ADDPAR") as EVENT_TYPE_CD length = 10
               format = $10.
               informat = $10.,
            ("RSK2PTY") as EVENT_DESC length = 256
               format = $256.
               informat = $256.,
            ("&ecm_user") as CREATE_USER_ID length = 60
               format = $60.
               informat = $60.,
            ("&current_dt"dt) as CREATE_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            ("PARTY") as LINKED_OBJECT_NM length = 100
               format = $100.
               informat = $100.,
            PARTY_RK as LINKED_OBJECT_RK
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W5YK2X44;

   proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_events;
   quit;
   
   data iem.new_events;
      attrib EVENT_RK length = 8
         format = 11.
         informat = 11.
         label = 'EVENT_RK';
      attrib BUSINESS_OBJECT_NM length = $100
         format = $100.
         informat = $100.
		 label = 'BUSINESS_OBJECT_NM';
      attrib BUSINESS_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'BUSINESS_OBJECT_RK'; 
      attrib EVENT_TYPE_CD length = $10
         format = $10.
         informat = $10.
         label = 'EVENT_TYPE_CD'; 
      attrib EVENT_DESC length = $256
         format = $256.
         informat = $256.
         label = 'EVENT_DESC'; 
      attrib CREATE_USER_ID length = $60
         format = $60.
         informat = $60.
         label = 'CREATE_USER_ID'; 
      attrib CREATE_DTTM length = 8
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'CREATE_DTTM'; 
      attrib LINKED_OBJECT_NM length = $100
         format = $100.
         informat = $100.
         label = 'LINKED_OBJECT_NM'; 
      attrib LINKED_OBJECT_RK length = 8
         format = 11.
         informat = 11.
         label = 'LINKED_OBJECT_RK'; 
      call missing(of _all_);
      stop;
   run;
   
proc append base = iem.new_events 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5YK2X44;
quit;

/*---- Start of Post-Process Code  ----*/ 

%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;
/*---- End of Post-Process Code  ----*/ 

/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002ZD * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Incident X Parties -              A5DG55RP.BH0001AR * 
 *                   iem.New_Incident_X_Parties                             * 
 * Target Table:    INCIDENT_X_PARTY -                    A5DG55RP.BH00019S * 
 *                   ecm_db.INCIDENT_X_PARTY                                * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.New_Incident_X_Parties); 

/*---- Map the columns  ----*/ 
proc datasets lib = work nolist nowarn memtype = (data view);
	delete W5YK2X4T;
quit;

proc sql;
  create view work.W5YK2X4T as
     select
        INCIDENT_RK,
        PARTY_RK,
        RELATION_TYPE_CD,
        RELATION_DESC,
        CREATE_DTTM
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W5YK2X4T;

proc append base = ecm_db.INCIDENT_X_PARTY 
	data = &SOURCEDS force ; 
run; 

proc datasets lib = work nolist nowarn memtype = (data view);
	delete W5YK2X4T;
quit;
  
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002ZE * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 

proc append base = ecm_db.ECM_EVENT 
	data = &SOURCEDS force ; 
run; 
   
 

%mend;
