%macro fcf_iem_update_associate;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV0002X4 * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   ASSOCIATE_TYPE1UPDATE -               A5DG55RP.BH0001A7 * 
 *                   iem.ASSOCIATE_TYPE1UPDATE                              * 
 *                  ASSOCIATE_TYPE2NEW -                  A5DG55RP.BH0001A8 * 
 *                   iem.ASSOCIATE_TYPE2NEW                                 * 
 * Target Table:    Append - work.W3IYGTXH                A5DG55RP.BR0001VO * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8G2OY6E;
quit;

proc sql;
   create view work.W8G2OY6E as
      select
         ASSOCIATE_key,
         ASSOCIATE_NUMBER,
         ASSOCIATE_FIRST_NAME,
         ASSOCIATE_LAST_NAME,
         ASSOCIATE_MIDDLE_NAME
   from iem.ASSOCIATE_TYPE1UPDATE
   ;
quit;

%let SOURCEDS = work.W8G2OY6E;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8G2OY6J;
quit;

proc sql;
   create view work.W8G2OY6J as
      select
         ASSOCIATE_key,
         ASSOCIATE_NUMBER,
         ASSOCIATE_FIRST_NAME,
         ASSOCIATE_LAST_NAME,
         ASSOCIATE_MIDDLE_NAME
   from iem.ASSOCIATE_TYPE2NEW
   ;
quit;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W3IYGTXH;
quit;

data work.W3IYGTXH / view=work.W3IYGTXH;
   set work.W8G2OY6E
       work.W8G2OY6J;
   keep ASSOCIATE_key ASSOCIATE_NUMBER ASSOCIATE_FIRST_NAME ASSOCIATE_LAST_NAME 
    ASSOCIATE_MIDDLE_NAME; 
run;


/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002X5 * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W3IYGTXH                A5DG55RP.BR0001VO * 
 * Target Table:    Extract - work.W227S7ML               A5DG55RP.BR0001VP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W3IYGTXH); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W227S7ML;
quit;

proc sql;
   create view work.W227S7ML as
      select
         ASSOCIATE_key,
         (CATX('-','ASC',ASSOCIATE_NUMBER)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID',
         (CATX(' ',ASSOCIATE_FIRST_NAME,ASSOCIATE_MIDDLE_NAME,ASSOCIATE_LAST_NAME)) as PARTY_FULL_NM length = 35
            format = $35.
            informat = $35.
            label = 'PARTY_FULL_NM'
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W227S7ML;


/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002X6 * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W227S7ML               A5DG55RP.BR0001VP * 
 *                  PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8G2OYC0;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8G2OYC0
         (keep = PARTY_RK VALID_FROM_DTTM VALID_TO_DTTM PARTY_ID SOURCE_SYSTEM_CD 
                 PARTY_TYPE_CD PARTY_CATEGORY_CD PARTY_SUBCATEGORY_CD 
                 IDENTICAL_PARTY_LINK_SK INDIVIDUAL_FLG PARTY_FULL_NM NATIONAL_ID 
                 NATIONAL_ID_TYPE_CD UI_DEF_FILE_NM CREATE_USER_ID CREATE_DTTM 
                 UPDATE_USER_ID VERSION_NO DELETE_FLG ASSOCIATE_key OLD_VALID_FROM_DTTM )
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          VALID_TO_DTTM length=8 format=DATETIME27.6 label="VALID_TO_DTTM"
          PARTY_ID length=$50 format=$50. label="PARTY_ID"
          SOURCE_SYSTEM_CD length=$10 format=$10. label="SOURCE_SYSTEM_CD"
          PARTY_TYPE_CD length=$32 format=$32. label="PARTY_TYPE_CD"
          PARTY_CATEGORY_CD length=$32 format=$32. label="PARTY_CATEGORY_CD"
          PARTY_SUBCATEGORY_CD length=$32 format=$32. label="PARTY_SUBCATEGORY_CD"
          IDENTICAL_PARTY_LINK_SK length=8 format=11. label="IDENTICAL_PARTY_LINK_SK"
          INDIVIDUAL_FLG length=$1 format=$1. label="INDIVIDUAL_FLG"
          PARTY_FULL_NM length=$35 format=$35. label="PARTY_FULL_NM"
          NATIONAL_ID length=$32 format=$32. label="NATIONAL_ID"
          NATIONAL_ID_TYPE_CD length=$10 format=$10. label="NATIONAL_ID_TYPE_CD"
          UI_DEF_FILE_NM length=$100 format=$100. label="UI_DEF_FILE_NM"
          CREATE_USER_ID length=$60 format=$60. label="CREATE_USER_ID"
          CREATE_DTTM length=8 format=DATETIME27.6 label="CREATE_DTTM"
          UPDATE_USER_ID length=$60 format=$60. label="UPDATE_USER_ID"
          VERSION_NO length=8 format=11. label="VERSION_NO"
          DELETE_FLG length=$1 format=$1. label="DELETE_FLG"
          ASSOCIATE_key length=8 format=BEST32. label="ASSOCIATE_key"
          OLD_VALID_FROM_DTTM length=8 format=DATETIME27.6 label="OLD_VALID_FROM_DTTM"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table ecm_db.PARTY_LIVE */ 
      nlobs = .; 
      dsid = open("ecm_db.PARTY_LIVE"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "ecm_db.PARTY_LIVE", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK",
                           "SOURCE_SYSTEM_CD",
                           "PARTY_TYPE_CD",
                           "PARTY_CATEGORY_CD",
                           "PARTY_SUBCATEGORY_CD",
                           "IDENTICAL_PARTY_LINK_SK",
                           "INDIVIDUAL_FLG",
                           "NATIONAL_ID",
                           "NATIONAL_ID_TYPE_CD",
                           "UI_DEF_FILE_NM",
                           "CREATE_USER_ID",
                           "CREATE_DTTM",
                           "UPDATE_USER_ID",
                           "DELETE_FLG",
                           "VERSION_NO",
                           "VALID_TO_DTTM",
                           "VALID_FROM_DTTM");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: ecm_db.PARTY_LIVE";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " ecm_db.PARTY_LIVE";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: ecm_db.PARTY_LIVE";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " ecm_db.PARTY_LIVE";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " ecm_db.PARTY_LIVE";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " ecm_db.PARTY_LIVE";
         
         abort 3; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, SOURCE_SYSTEM_CD, PARTY_TYPE_CD, 
                    PARTY_CATEGORY_CD, PARTY_SUBCATEGORY_CD, IDENTICAL_PARTY_LINK_SK, 
                    INDIVIDUAL_FLG, NATIONAL_ID, NATIONAL_ID_TYPE_CD, UI_DEF_FILE_NM, 
                    CREATE_USER_ID, CREATE_DTTM, UPDATE_USER_ID, DELETE_FLG, 
                    VERSION_NO, VALID_TO_DTTM, VALID_FROM_DTTM); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W227S7ML end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_ID);
   OLD_VALID_FROM_DTTM = VALID_FROM_DTTM;
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8G2OYC0; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Abort  */ 
         abort 4; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

data _null_;
  call symput('current_dt',put(datetime(),datetime22.));
run;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2288GWR;
quit;

proc sql;
   create table work.W2288GWR as
      select
         PARTY_RK,
         ("&current_dt"dt) as VALID_FROM_DTTM length = 8
            format = DATETIME27.6
            informat = DATETIME27.6
            label = 'VALID_FROM_DTTM',
         VALID_TO_DTTM,
         PARTY_ID,
         SOURCE_SYSTEM_CD,
         PARTY_TYPE_CD,
         PARTY_CATEGORY_CD,
         PARTY_SUBCATEGORY_CD,
         IDENTICAL_PARTY_LINK_SK,
         INDIVIDUAL_FLG,
         PARTY_FULL_NM,
         NATIONAL_ID,
         NATIONAL_ID_TYPE_CD,
         UI_DEF_FILE_NM,
         CREATE_USER_ID,
         CREATE_DTTM,
         UPDATE_USER_ID,
         VERSION_NO,
         DELETE_FLG,
         ASSOCIATE_key,
         OLD_VALID_FROM_DTTM
   from work.W8G2OYC0
   ;
quit;

%let SOURCEDS = work.W2288GWR;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8G2OYC0;
quit;

/**  Step end Lookup **/

/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV0002X7 * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 * Target Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 *                                                                          * 
 * User Written:    SourceCode                                              * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
   update ecm_db.PARTY_LIVE
      set 
         VALID_FROM_DTTM= (
            select
               W2288GWR.VALID_FROM_DTTM length = 8   
                  format = DATETIME27.6
                  informat = DATETIME27.6
                  label = 'VALID_FROM_DTTM'
            from
               work.W2288GWR as W2288GWR
            where
               PARTY_LIVE.PARTY_RK = W2288GWR.PARTY_RK
         ),
         VERSION_NO= VERSION_NO + 1
      where
         PARTY_RK IN (
            select
               W2288GWR.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W2288GWR as W2288GWR
         )
   ;
quit;

/**  Step end Update **/

/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV0002X8 * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
   update ecm_db.PARTY_VERSION
      set 
         VALID_TO_DTTM= (
            select
               W2288GWR.VALID_FROM_DTTM length = 8   
                  format = DATETIME27.6
                  informat = DATETIME27.6
                  label = 'VALID_FROM_DTTM'
            from
               work.W2288GWR as W2288GWR
            where
               PARTY_VERSION.PARTY_RK = W2288GWR.PARTY_RK
         )
      where
         VALID_TO_DTTM = .
         and PARTY_RK IN (
            select
               W2288GWR.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W2288GWR as W2288GWR
         )
   ;
quit;

/**  Step end Update **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002X9 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
      create view work.W8G2OYZ2 as
         select
            PARTY_RK,
            VALID_FROM_DTTM,
            . as VALID_TO_DTTM length = 8
               format = DATETIME27.6
               informat = DATETIME27.6,
            PARTY_ID,
            SOURCE_SYSTEM_CD,
            PARTY_TYPE_CD,
            PARTY_CATEGORY_CD,
            PARTY_SUBCATEGORY_CD,
            IDENTICAL_PARTY_LINK_SK,
            INDIVIDUAL_FLG,
            PARTY_FULL_NM length = 100   
               format = $100.
               informat = $100.,
            NATIONAL_ID,
            NATIONAL_ID_TYPE_CD,
            UI_DEF_FILE_NM,
            CREATE_USER_ID,
            CREATE_DTTM,
            UPDATE_USER_ID,
            (VERSION_NO+1) as VERSION_NO length = 8
               format = 11.
               informat = 11.,
            DELETE_FLG
      from &SOURCEDS
      ;
   quit;
   
   %let SOURCEDS = work.W8G2OYZ2;
   
   proc append base = ecm_db.PARTY_VERSION 
      data = &SOURCEDS force ; 
    run; 
   
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W8G2OYZ2;
   quit;
   
/**  Step end Table Loader **/

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XA * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8G2OZ49;
quit;

proc sql;
  create view work.W8G2OZ49 as
     select
        . as EVENT_RK length = 8
           format = 11.
           informat = 11.,
        ("PARTY") as BUSINESS_OBJECT_NM length = 100
           format = $100.
           informat = $100.,
        PARTY_RK as BUSINESS_OBJECT_RK,
        ("SAVENT") as EVENT_TYPE_CD length = 10
           format = $10.
           informat = $10.,
        "" as EVENT_DESC length = 256
           format = $256.
           informat = $256.,
        CREATE_USER_ID,
        VALID_FROM_DTTM as CREATE_DTTM,
        "" as LINKED_OBJECT_NM length = 100
           format = $100.
           informat = $100.,
        . as LINKED_OBJECT_RK length = 8
           format = 11.
           informat = 11.
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8G2OZ49;

proc datasets lib = iem nolist nowarn memtype = (data view);
      delete new_events;
quit;
   
data iem.new_events;
  attrib EVENT_RK length = 8
     format = 11.
     informat = 11.
     label = 'EVENT_RK'; 
  attrib BUSINESS_OBJECT_NM length = $100
     format = $100.
     informat = $100.
     label = 'BUSINESS_OBJECT_NM'; 
  attrib BUSINESS_OBJECT_RK length = 8
     format = 11.
     informat = 11.
     label = 'BUSINESS_OBJECT_RK'; 
  attrib EVENT_TYPE_CD length = $10
     format = $10.
     informat = $10.
     label = 'EVENT_TYPE_CD'; 
  attrib EVENT_DESC length = $256
     format = $256.
     informat = $256.
     label = 'EVENT_DESC'; 
  attrib CREATE_USER_ID length = $60
     format = $60.
     informat = $60.
     label = 'CREATE_USER_ID'; 
  attrib CREATE_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'CREATE_DTTM'; 
  attrib LINKED_OBJECT_NM length = $100
     format = $100.
     informat = $100.
     label = 'LINKED_OBJECT_NM'; 
  attrib LINKED_OBJECT_RK length = 8
     format = 11.
     informat = 11.
     label = 'LINKED_OBJECT_RK'; 
  call missing(of _all_);
  stop;
run;

proc append base = iem.new_events 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8G2OZ49;
quit;


%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XB * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT             A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 
   
proc append base = ecm_db.ECM_EVENT 
  data = &SOURCEDS force ; 
run; 


/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV00030U * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 * Target Table:    Extract - work.W55GKIIY               A5DG55RP.BR0001XR * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W55GKIIY;
quit;

proc sql;
   create view work.W55GKIIY as
      select
         PARTY_RK,
         VALID_FROM_DTTM,
         ASSOCIATE_key as X_SASFCS_PTY_KEY
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W55GKIIY;


/*==========================================================================* 
 * Step:            Sort                                  A5DG55RP.BV00034R * 
 * Transform:       Sort                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Extract - work.W55GKIIY               A5DG55RP.BR0001XR * 
 * Target Table:    Sort - work.W8G0J6H3                  A5DG55RP.BR000208 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W55GKIIY); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8G0J6H3;
quit;

proc sort data = &SOURCEDS 
   out = work.W8G0J6H3; 
   by
      PARTY_RK
      VALID_FROM_DTTM
   ;
run; 


/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV00030V * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Sort - work.W8G0J6H3                  A5DG55RP.BR000208 * 
 * Target Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W8G0J6H3); 

%let _INPUT = work.W8G0J6H3;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Subject_Numeric_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Subject_Numeric_Udf_Fields;
quit;

%let varColumns = X_SASFCS_PTY_KEY;
%let byColumns = PARTY_RK VALID_FROM_DTTM;

options mprint;

proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);
  by &byColumns;
  var &varColumns;
run;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00030W * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 * Target Table:    New Numeric UDFs -                    A5DG55RP.BH0001BK * 
 *                   iem.New_Numeric_UDFs                                   * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Subject_Numeric_Udf_Fields); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8OKGXAB;
quit;

proc sql;
  create view work.W8OKGXAB as
     select
        PARTY_RK,
        VALID_FROM_DTTM,
        ("PARTY") as UDF_TABLE_NM length = 30
           format = $30.
           informat = $30.,
        _NAME_ as UDF_NM length = 30   
           format = $30.
           informat = $30.,
        (1) as ROW_NO length = 8
           format = 11.
           informat = 11.,
        COL1 as UDF_VALUE
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8OKGXAB;

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete New_Numeric_UDFs;
quit;
  
data iem.New_Numeric_UDFs;
  attrib PARTY_RK length = 8
     format = 11.
     informat = 11.
     label = 'PARTY_RK'; 
  attrib VALID_FROM_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'VALID_FROM_DTTM'; 
  attrib UDF_TABLE_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_TABLE_NM'; 
  attrib UDF_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_NM'; 
  attrib ROW_NO length = 8
     format = 11.
     informat = 11.
     label = 'ROW_NO'; 
  attrib UDF_VALUE length = 8
     label = 'UDF_VALUE'; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.New_Numeric_UDFs 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8OKGXAB;
quit;

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV000340 * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 *                  PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 * Target Table:    Join - work.W7KVS8PK                  A5DG55RP.BR0001ZT * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KVS8PK;
quit;

proc sql;
   create view work.W7KVS8PK as
   select
      PARTY_UDF_NUM_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_NUM_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_NUM_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_NUM_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_NUM_VALUE.UDF_VALUE length = 8   
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_NUM_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_NUM_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_NUM_VALUE.VALID_FROM_DTTM
      and PARTY_UDF_NUM_VALUE.UDF_NM NOT IN ('X_SASFCS_PTY_KEY')
   ;
quit;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV000341 * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   New Numeric UDFs -                    A5DG55RP.BH0001BK * 
 *                   iem.New_Numeric_UDFs                                   * 
 *                  Join - work.W7KVS8PK                  A5DG55RP.BR0001ZT * 
 * Target Table:    Append - work.W7KWXOIW                A5DG55RP.BR0001ZU * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KWXOIW;
quit;

data work.W7KWXOIW / view=work.W7KWXOIW;
   set iem.New_Numeric_UDFs
       work.W7KVS8PK;
   keep PARTY_RK VALID_FROM_DTTM UDF_TABLE_NM UDF_NM ROW_NO UDF_VALUE; 
run;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV000342 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W7KWXOIW                A5DG55RP.BR0001ZU * 
 * Target Table:    PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7KWXOIW); 
   
proc append base = ecm_db.PARTY_UDF_NUM_VALUE 
  data = &SOURCEDS force ; 
run; 

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV000343 * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 *                  PARTY_UDF_CHAR_VALUE -                A5DG55RP.BH00019X * 
 *                   ecm_db.PARTY_UDF_CHAR_VALUE                            * 
 * Target Table:    Join - work.W7LCLZ88                  A5DG55RP.BR0001ZV * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7LCLZ88;
quit;

proc sql;
   create table work.W7LCLZ88 as
   select
      PARTY_UDF_CHAR_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_CHAR_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_CHAR_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_CHAR_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_CHAR_VALUE.UDF_VALUE length = 4000   
         format = $4000.
         informat = $4000.
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_CHAR_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_CHAR_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_CHAR_VALUE.VALID_FROM_DTTM
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV000346 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W7LCLZ88                  A5DG55RP.BR0001ZV * 
 * Target Table:    PARTY_UDF_CHAR_VALUE -                A5DG55RP.BH00019X * 
 *                   ecm_db.PARTY_UDF_CHAR_VALUE                            * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7LCLZ88); 
   
proc append base = ecm_db.PARTY_UDF_CHAR_VALUE 
  data = &SOURCEDS force ; 
run; 

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV000344 * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 *                  PARTY_UDF_DATE_VALUE -                A5DG55RP.BH0001BL * 
 *                   ecm_db.PARTY_UDF_DATE_VALUE                            * 
 * Target Table:    Join - work.W7LCMRQX                  A5DG55RP.BR0001ZW * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7LCMRQX;
quit;

proc sql;
   create table work.W7LCMRQX as
   select
      PARTY_UDF_DATE_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_DATE_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_DATE_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_DATE_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_DATE_VALUE.UDF_VALUE length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_DATE_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_DATE_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_DATE_VALUE.VALID_FROM_DTTM
   ;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV000347 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W7LCMRQX                  A5DG55RP.BR0001ZW * 
 * Target Table:    PARTY_UDF_DATE_VALUE -                A5DG55RP.BH0001BL * 
 *                   ecm_db.PARTY_UDF_DATE_VALUE                            * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7LCMRQX); 
   
proc append base = ecm_db.PARTY_UDF_DATE_VALUE 
  data = &SOURCEDS force ; 
run; 
   

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV000345 * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VQ * 
 *                  PARTY_UDF_LGCHR_VALUE -               A5DG55RP.BH0001BN * 
 *                   ecm_db.PARTY_UDF_LGCHR_VALUE                           * 
 * Target Table:    Join - work.W7LCNEBR                  A5DG55RP.BR0001ZX * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7LCNEBR;
quit;

proc sql;
   create table work.W7LCNEBR as
   select
      PARTY_UDF_LGCHR_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_LGCHR_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_LGCHR_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_LGCHR_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_LGCHR_VALUE.UDF_VALUE length = 1024   
         format = $1024.
         informat = $1024.
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_LGCHR_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_LGCHR_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_LGCHR_VALUE.VALID_FROM_DTTM
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV000348 * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W7LCNEBR                  A5DG55RP.BR0001ZX * 
 * Target Table:    PARTY_UDF_LGCHR_VALUE -               A5DG55RP.BH0001BN * 
 *                   ecm_db.PARTY_UDF_LGCHR_VALUE                           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7LCNEBR); 
   
proc append base = ecm_db.PARTY_UDF_LGCHR_VALUE 
  data = &SOURCEDS force ; 
run; 
  

%mend;
