%macro fcf_iem_update_household;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV0002XD * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   HOUSEHOLD_TYPE1UPDATE -               A5DG55RP.BH0001AF * 
 *                   iem.HOUSEHOLD_TYPE1UPDATE                              * 
 *                  HOUSEHOLD_TYPE2NEW -                  A5DG55RP.BH0001AG * 
 *                   iem.HOUSEHOLD_TYPE2NEW                                 * 
 * Target Table:    Append - work.W3IYGTXH                A5DG55RP.BR0001VR * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8P2JAJH;
quit;

proc sql;
   create view work.W8P2JAJH as
      select
         HOUSEHOLD_key,
         HOUSEHOLD_NUMBER,
         HEAD_OF_HOUSEHOLD_NAME
   from iem.HOUSEHOLD_TYPE1UPDATE
   ;
quit;

%let SOURCEDS = work.W8P2JAJH;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8P2JAJL;
quit;

proc sql;
   create view work.W8P2JAJL as
      select
         HOUSEHOLD_key,
         HOUSEHOLD_NUMBER,
         HEAD_OF_HOUSEHOLD_NAME
   from iem.HOUSEHOLD_TYPE2NEW
   ;
quit;

%let SOURCEDS = work.W8P2JAJL;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W3IYGTXH;
quit;

data work.W3IYGTXH / view=work.W3IYGTXH;
   set work.W8P2JAJH
       work.W8P2JAJL;
   keep HOUSEHOLD_key HOUSEHOLD_NUMBER HEAD_OF_HOUSEHOLD_NAME; 
run;


/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV0002XE * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W3IYGTXH                A5DG55RP.BR0001VR * 
 * Target Table:    Extract - work.W227S7ML               A5DG55RP.BR0001VS * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W3IYGTXH); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W227S7ML;
quit;

proc sql;
   create view work.W227S7ML as
      select
         HOUSEHOLD_key,
         (CATX('-','HHD',HOUSEHOLD_NUMBER)) as PARTY_ID length = 50
            format = $50.
            informat = $50.
            label = 'PARTY_ID',
         HEAD_OF_HOUSEHOLD_NAME as PARTY_FULL_NM   
            label = 'PARTY_FULL_NM'
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W227S7ML;

/*==========================================================================* 
 * Step:            Lookup                                A5DG55RP.BV0002XF * 
 * Transform:       Lookup                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Extract - work.W227S7ML               A5DG55RP.BR0001VS * 
 *                  PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 * Target Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8P2JAPO;
quit;

/*---- Begin DATA step to perform lookups  ----*/ 
DATA  work.W8P2JAPO
         (keep = PARTY_RK VALID_FROM_DTTM VALID_TO_DTTM PARTY_ID SOURCE_SYSTEM_CD 
                 PARTY_TYPE_CD PARTY_CATEGORY_CD PARTY_SUBCATEGORY_CD 
                 IDENTICAL_PARTY_LINK_SK INDIVIDUAL_FLG PARTY_FULL_NM NATIONAL_ID 
                 NATIONAL_ID_TYPE_CD UI_DEF_FILE_NM CREATE_USER_ID CREATE_DTTM 
                 UPDATE_USER_ID VERSION_NO DELETE_FLG HOUSEHOLD_key OLD_VALID_FROM_DTTM )
      ; 
   
   attrib PARTY_RK length=8 format=11. label="PARTY_RK"
          VALID_FROM_DTTM length=8 format=DATETIME27.6 label="VALID_FROM_DTTM"
          VALID_TO_DTTM length=8 format=DATETIME27.6 label="VALID_TO_DTTM"
          PARTY_ID length=$50 format=$50. label="PARTY_ID"
          SOURCE_SYSTEM_CD length=$10 format=$10. label="SOURCE_SYSTEM_CD"
          PARTY_TYPE_CD length=$32 format=$32. label="PARTY_TYPE_CD"
          PARTY_CATEGORY_CD length=$32 format=$32. label="PARTY_CATEGORY_CD"
          PARTY_SUBCATEGORY_CD length=$32 format=$32. label="PARTY_SUBCATEGORY_CD"
          IDENTICAL_PARTY_LINK_SK length=8 format=11. label="IDENTICAL_PARTY_LINK_SK"
          INDIVIDUAL_FLG length=$1 format=$1. label="INDIVIDUAL_FLG"
          PARTY_FULL_NM length=$35 format=$35. label="PARTY_FULL_NM"
          NATIONAL_ID length=$32 format=$32. label="NATIONAL_ID"
          NATIONAL_ID_TYPE_CD length=$10 format=$10. label="NATIONAL_ID_TYPE_CD"
          UI_DEF_FILE_NM length=$100 format=$100. label="UI_DEF_FILE_NM"
          CREATE_USER_ID length=$60 format=$60. label="CREATE_USER_ID"
          CREATE_DTTM length=8 format=DATETIME27.6 label="CREATE_DTTM"
          UPDATE_USER_ID length=$60 format=$60. label="UPDATE_USER_ID"
          VERSION_NO length=8 format=11. label="VERSION_NO"
          DELETE_FLG length=$1 format=$1. label="DELETE_FLG"
          HOUSEHOLD_key length=8 format=BEST32. label="household_key"
          OLD_VALID_FROM_DTTM length=8 format=DATETIME27.6 label="OLD_VALID_FROM_DTTM"
          ; 
   
   retain missing0-missing0 0; 
   
   etls_assign_target_value = 0; 
   /* Build hash objects from lookup tables before reading first source row  */ 
   if (_n_ = 1) then 
   do; 
      /* Build hash h0 from lookup table ecm_db.PARTY_LIVE */ 
      nlobs = .; 
      dsid = open("ecm_db.PARTY_LIVE"); 
      if (dsid > 0) then 
      do; 
         if ( attrc(dsid, 'MTYPE') = 'DATA' ) then 
            nlobs = attrn(dsid, 'NLOBS'); 
         else 
            nlobs = -1; 
            
         dsid = close(dsid); 
         if (nlobs ^= 0) then 
         do; 
            if (nlobs > 0) then 
               exponent = ceil(log2(nlobs)); 
            else 
               exponent = 8; 
            declare hash h0(dataset: "ecm_db.PARTY_LIVE", hashexp: exponent);
            h0.defineKey( "PARTY_ID");
            h0.defineData( "PARTY_RK",
                           "SOURCE_SYSTEM_CD",
                           "PARTY_TYPE_CD",
                           "PARTY_CATEGORY_CD",
                           "PARTY_SUBCATEGORY_CD",
                           "IDENTICAL_PARTY_LINK_SK",
                           "INDIVIDUAL_FLG",
                           "NATIONAL_ID",
                           "NATIONAL_ID_TYPE_CD",
                           "UI_DEF_FILE_NM",
                           "CREATE_USER_ID",
                           "CREATE_DTTM",
                           "UPDATE_USER_ID",
                           "DELETE_FLG",
                           "VERSION_NO",
                           "VALID_TO_DTTM",
                           "VALID_FROM_DTTM");
            h0.defineDone();
            if (nlobs = -1) then 
            do; 
               if (h0.Num_Items < 1) then
               do; 
                  put "NOTE: Lookup table is empty: ecm_db.PARTY_LIVE";
                  put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                       " ecm_db.PARTY_LIVE";
                  
                  abort 3; 
               end; 
            end; 
         end; 
         else 
         do; 
            put "NOTE: Lookup table is empty: ecm_db.PARTY_LIVE";
            put "NOTE: Abort action indicated, condition= Lookup table is empty:"
                 " ecm_db.PARTY_LIVE";
            
            abort 3; 
         end; 
      end; 
      else 
      do; 
         put "NOTE: Lookup table does not exist or cannot be opened:"
              " ecm_db.PARTY_LIVE";
         
         put "NOTE: Abort action indicated, condition= Lookup table missing:"
              " ecm_db.PARTY_LIVE";
         
         abort 3; 
      end; 
      
      call missing (PARTY_ID, PARTY_RK, SOURCE_SYSTEM_CD, PARTY_TYPE_CD, 
                    PARTY_CATEGORY_CD, PARTY_SUBCATEGORY_CD, IDENTICAL_PARTY_LINK_SK, 
                    INDIVIDUAL_FLG, NATIONAL_ID, NATIONAL_ID_TYPE_CD, UI_DEF_FILE_NM, 
                    CREATE_USER_ID, CREATE_DTTM, UPDATE_USER_ID, DELETE_FLG, 
                    VERSION_NO, VALID_TO_DTTM, VALID_FROM_DTTM); 
   
   end; /* All hash objects have been defined */
   
   /* Read a row from the source table  */ 
   set work.W227S7ML end = eof;
   
   /* Is the current key value stored in hash h0?  */ 
   rc0 = h0.find(key: PARTY_ID);
   OLD_VALID_FROM_DTTM = VALID_FROM_DTTM;
   /* Examine success of lookups  */ 
   if ( rc0=0 ) then 
   do; 
      /* Write row to target  */ 
      output work.W8P2JAPO; 
   end; 
   else 
   do; 
      error_total + 1; 
      
      if (rc0 ^= 0) then 
      do; 
         exception_total + 1; 
         /* Check: Lookup value not found-Abort  */ 
         abort 4; 
      end; 
   
   end; /* One or more lookups failed */
   
   if (eof = 1) then 
   do; 
      put "Source records with errors: " error_total ; 
      put "Total lookup exceptions: " exception_total ; 
   end; 

run; 

data _null_;
  call symput('current_dt',put(datetime(),datetime22.));
run;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W2288GWR;
quit;

proc sql;
   create table work.W2288GWR as
      select
         PARTY_RK,
         ("&current_dt"dt) as VALID_FROM_DTTM length = 8
            format = DATETIME27.6
            informat = DATETIME27.6
            label = 'VALID_FROM_DTTM',
         VALID_TO_DTTM,
         PARTY_ID,
         SOURCE_SYSTEM_CD,
         PARTY_TYPE_CD,
         PARTY_CATEGORY_CD,
         PARTY_SUBCATEGORY_CD,
         IDENTICAL_PARTY_LINK_SK,
         INDIVIDUAL_FLG,
         PARTY_FULL_NM,
         NATIONAL_ID,
         NATIONAL_ID_TYPE_CD,
         UI_DEF_FILE_NM,
         CREATE_USER_ID,
         CREATE_DTTM,
         UPDATE_USER_ID,
         VERSION_NO,
         DELETE_FLG,
         HOUSEHOLD_key,
         OLD_VALID_FROM_DTTM
   from work.W8P2JAPO
   ;
quit;

%let SOURCEDS = work.W2288GWR;

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8P2JAPO;
quit;


/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV0002XG * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 * Target Table:    PARTY_LIVE - ecm_db.PARTY_LIVE        A5DG55RP.BH00019W * 
 *                                                                          * 
 * User Written:    SourceCode                                              * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
   update ecm_db.PARTY_LIVE
      set 
         VALID_FROM_DTTM= (
            select
               W2288GWR.VALID_FROM_DTTM length = 8   
                  format = DATETIME27.6
                  informat = DATETIME27.6
                  label = 'VALID_FROM_DTTM'
            from
               work.W2288GWR as W2288GWR
            where
               PARTY_LIVE.PARTY_RK = W2288GWR.PARTY_RK
         ),
         VERSION_NO= VERSION_NO + 1
      where
         PARTY_RK IN (
            select
               W2288GWR.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W2288GWR as W2288GWR
         )
   ;
quit;

/*==========================================================================* 
 * Step:            Update                                A5DG55RP.BV0002XH * 
 * Transform:       Update                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc sql;
   update ecm_db.PARTY_VERSION
      set 
         VALID_TO_DTTM= (
            select
               W2288GWR.VALID_FROM_DTTM length = 8   
                  format = DATETIME27.6
                  informat = DATETIME27.6
                  label = 'VALID_FROM_DTTM'
            from
               work.W2288GWR as W2288GWR
            where
               PARTY_VERSION.PARTY_RK = W2288GWR.PARTY_RK
         )
      where
         VALID_TO_DTTM = .
         and PARTY_RK IN (
            select
               W2288GWR.PARTY_RK length = 8   
                  format = 11.
                  informat = 11.
                  label = 'PARTY_RK'
            from
               work.W2288GWR as W2288GWR
         )
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XI * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 * Target Table:    PARTY_VERSION - ecm_db.PARTY_VERSION  A5DG55RP.BH00019Z * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W8P2JBG9;
quit;

proc sql;
  create view work.W8P2JBG9 as
     select
        PARTY_RK,
        VALID_FROM_DTTM,
        . as VALID_TO_DTTM length = 8
           format = DATETIME27.6
           informat = DATETIME27.6,
        PARTY_ID,
        SOURCE_SYSTEM_CD,
        PARTY_TYPE_CD,
        PARTY_CATEGORY_CD,
        PARTY_SUBCATEGORY_CD,
        IDENTICAL_PARTY_LINK_SK,
        INDIVIDUAL_FLG,
        PARTY_FULL_NM length = 100   
           format = $100.
           informat = $100.,
        NATIONAL_ID,
        NATIONAL_ID_TYPE_CD,
        UI_DEF_FILE_NM,
        CREATE_USER_ID,
        CREATE_DTTM,
        UPDATE_USER_ID,
        (VERSION_NO+1) as VERSION_NO length = 8
           format = 11.
           informat = 11.,
        DELETE_FLG
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8P2JBG9;

proc append base = ecm_db.PARTY_VERSION 
  data = &SOURCEDS force ; 
run; 
  
proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8P2JBG9;
quit;
   
/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XJ * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 * Target Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 

proc datasets lib = work nolist nowarn memtype = (data view);
      delete W8P2JBL9;
quit;

proc sql;
  create view work.W8P2JBL9 as
     select
        . as EVENT_RK length = 8
           format = 11.
           informat = 11.,
        ("PARTY") as BUSINESS_OBJECT_NM length = 100
           format = $100.
           informat = $100.,
        PARTY_RK as BUSINESS_OBJECT_RK,
        ("SAVENT") as EVENT_TYPE_CD length = 10
           format = $10.
           informat = $10.,
        "" as EVENT_DESC length = 256
           format = $256.
           informat = $256.,
        CREATE_USER_ID,
        VALID_FROM_DTTM as CREATE_DTTM,
        "" as LINKED_OBJECT_NM length = 100
           format = $100.
           informat = $100.,
        . as LINKED_OBJECT_RK length = 8
           format = 11.
           informat = 11.
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8P2JBL9;
proc datasets lib = iem nolist nowarn memtype = (data view);
  delete new_events;
quit;

data iem.new_events;
  attrib EVENT_RK length = 8
     format = 11.
     informat = 11.
     label = 'EVENT_RK'; 
  attrib BUSINESS_OBJECT_NM length = $100
     format = $100.
     informat = $100.
     label = 'BUSINESS_OBJECT_NM'; 
  attrib BUSINESS_OBJECT_RK length = 8
     format = 11.
     informat = 11.
     label = 'BUSINESS_OBJECT_RK'; 
  attrib EVENT_TYPE_CD length = $10
     format = $10.
     informat = $10.
     label = 'EVENT_TYPE_CD'; 
  attrib EVENT_DESC length = $256
     format = $256.
     informat = $256.
     label = 'EVENT_DESC'; 
  attrib CREATE_USER_ID length = $60
     format = $60.
     informat = $60.
     label = 'CREATE_USER_ID'; 
  attrib CREATE_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'CREATE_DTTM'; 
  attrib LINKED_OBJECT_NM length = $100
     format = $100.
     informat = $100.
     label = 'LINKED_OBJECT_NM'; 
  attrib LINKED_OBJECT_RK length = 8
     format = 11.
     informat = 11.
     label = 'LINKED_OBJECT_RK'; 
  call missing(of _all_);
  stop;
run;
   
proc append base = iem.new_events 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8P2JBL9;
quit;


%let obs_count = %fcf_get_observation_count(table=iem.new_events, SASDATASET=Y);
%let numevents = &obs_count;

%fcf_get_ecm_sequence_ids(numIDs=&numevents, ecmSeq=event);

data iem.new_events;
	set iem.new_events;
	event_rk = symgetn('seqId'||(kstrip(put(_n_,best32.))));
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV0002XK * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    New Events - iem.new_events           A5DG55RP.BH0001AP * 
 * Target Table:    ECM_EVENT - ecm_db.ECM_EVENT          A5DG55RP.BH00019J * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.new_events); 
   
proc append base = ecm_db.ECM_EVENT 
  data = &SOURCEDS force ; 
run; 
 
/*==========================================================================* 
 * Step:            Extract                               A5DG55RP.BV00030R * 
 * Transform:       Extract                                                 * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 * Target Table:    Extract - work.W5404G2X               A5DG55RP.BR0001XQ * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W2288GWR); 
proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5404G2X;
quit;

proc sql;
   create view work.W5404G2X as
      select
         PARTY_RK,
         VALID_FROM_DTTM,
         HOUSEHOLD_key as X_SASFCS_PTY_KEY
   from &SOURCEDS
   ;
quit;

%let SOURCEDS = work.W5404G2X;

/*==========================================================================* 
 * Step:            Sort                                  A5DG55RP.$0006556 * 
 * Transform:       Sort                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Extract - work.W5404G2X               A5DG55RP.BR0001XQ * 
 * Target Table:    Sort - work.W8QCB7BA                  A5DG55RP.$0006559 * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W5404G2X); 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8QCB7BA;
quit;

proc sort data = &SOURCEDS 
   out = work.W8QCB7BA; 
   by
      PARTY_RK
      VALID_FROM_DTTM
   ;
run; 


/*==========================================================================* 
 * Step:            Transpose                             A5DG55RP.BV00030S * 
 * Transform:       Transpose                                               * 
 * Description:     Creates an output table by restructuring the values in  * 
 *                  the source table, transposing selected columns into     * 
 *                   rows.                                                  * 
 *                                                                          * 
 * Source Table:    Extract - work.W8QCB7BA               A5DG55RP.BR0001XQ * 
 * Target Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W8QCB7BA); 

%let _INPUT = work.W5404G2X;
%let _INPUT_options = %nrquote();

%let _OUTPUT = iem.Subject_Numeric_Udf_Fields;
%let _OUTPUT_options = %nrquote();

proc datasets lib=iem nolist nowarn memtype = (data view);
   delete Subject_Numeric_Udf_Fields;
quit;

%let varColumns = X_SASFCS_PTY_KEY;
%let byColumns = PARTY_RK VALID_FROM_DTTM;

options mprint;

proc transpose data = &_INPUT (&_INPUT_options) out = &_OUTPUT (&_OUTPUT_options);
by &byColumns;
var &varColumns;
run;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00030T * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Subject Numeric UDF Fields -          A5DG55RP.BH0001B0 * 
 *                   iem.Subject_Numeric_Udf_Fields                         * 
 * Target Table:    New Numeric UDFs -                    A5DG55RP.BH0001BK * 
 *                   iem.New_Numeric_UDFs                                   * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(iem.Subject_Numeric_Udf_Fields); 

proc datasets lib = work nolist nowarn memtype = (data view);
  delete W8P2JCQ1;
quit;

proc sql;
  create view work.W8P2JCQ1 as
     select
        PARTY_RK,
        VALID_FROM_DTTM,
        ('PARTY') as UDF_TABLE_NM length = 30
           format = $30.
           informat = $30.,
        _NAME_ as UDF_NM length = 30   
           format = $30.
           informat = $30.,
        (1) as ROW_NO length = 8
           format = 11.
           informat = 11.,
        COL1 as UDF_VALUE
  from &SOURCEDS
  ;
quit;

%let SOURCEDS = work.W8P2JCQ1;

proc datasets lib = iem nolist nowarn memtype = (data view);
  delete New_Numeric_UDFs;
quit;

data iem.New_Numeric_UDFs;
  attrib PARTY_RK length = 8
     format = 11.
     informat = 11.
     label = 'PARTY_RK'; 
  attrib VALID_FROM_DTTM length = 8
     format = DATETIME27.6
     informat = DATETIME27.6
     label = 'VALID_FROM_DTTM'; 
  attrib UDF_TABLE_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_TABLE_NM'; 
  attrib UDF_NM length = $30
     format = $30.
     informat = $30.
     label = 'UDF_NM'; 
  attrib ROW_NO length = 8
     format = 11.
     informat = 11.
     label = 'ROW_NO'; 
  attrib UDF_VALUE length = 8
     label = 'UDF_VALUE'; 
  call missing(of _all_);
  stop;
run;

proc append base = iem.New_Numeric_UDFs 
   data = &SOURCEDS force ; 
 run; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W8P2JCQ1;
quit;

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033R * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 *                  PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 * Target Table:    Join - work.W7KMAOES                  A5DG55RP.BR0001ZO * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KMAOES;
quit;

proc sql;
   create view work.W7KMAOES as
   select
      PARTY_UDF_NUM_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_NUM_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_NUM_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_NUM_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_NUM_VALUE.UDF_VALUE length = 8   
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_NUM_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_NUM_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_NUM_VALUE.VALID_FROM_DTTM
      and PARTY_UDF_NUM_VALUE.UDF_NM NOT IN ('X_SASFCS_PTY_KEY')
   ;
quit;

/*==========================================================================* 
 * Step:            Append                                A5DG55RP.BV00033S * 
 * Transform:       Append                                                  * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   New Numeric UDFs -                    A5DG55RP.BH0001BK * 
 *                   iem.New_Numeric_UDFs                                   * 
 *                  Join - work.W7KMAOES                  A5DG55RP.BR0001ZO * 
 * Target Table:    Append - work.W7KMN8LC                A5DG55RP.BR0001ZP * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KMN8LC;
quit;

data work.W7KMN8LC / view=work.W7KMN8LC;
   set iem.New_Numeric_UDFs
       work.W7KMAOES;
   keep PARTY_RK VALID_FROM_DTTM UDF_TABLE_NM UDF_NM ROW_NO UDF_VALUE; 
run;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033T * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Append - work.W7KMN8LC                A5DG55RP.BR0001ZP * 
 * Target Table:    PARTY_UDF_NUM_VALUE -                 A5DG55RP.BH00019Y * 
 *                   ecm_db.PARTY_UDF_NUM_VALUE                             * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7KMN8LC); 
   
   proc append base = ecm_db.PARTY_UDF_NUM_VALUE 
      data = &SOURCEDS force ; 
    run; 
   

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033U * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 *                  PARTY_UDF_CHAR_VALUE -                A5DG55RP.BH00019X * 
 *                   ecm_db.PARTY_UDF_CHAR_VALUE                            * 
 * Target Table:    Join - work.W7KP78VD                  A5DG55RP.BR0001ZQ * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KP78VD;
quit;

proc sql;
   create table work.W7KP78VD as
   select
      PARTY_UDF_CHAR_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_CHAR_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_CHAR_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_CHAR_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_CHAR_VALUE.UDF_VALUE length = 4000   
         format = $4000.
         informat = $4000.
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_CHAR_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_CHAR_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_CHAR_VALUE.VALID_FROM_DTTM
   ;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033X * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W7KP78VD                  A5DG55RP.BR0001ZQ * 
 * Target Table:    PARTY_UDF_CHAR_VALUE -                A5DG55RP.BH00019X * 
 *                   ecm_db.PARTY_UDF_CHAR_VALUE                            * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7KP78VD); 
   
proc append base = ecm_db.PARTY_UDF_CHAR_VALUE 
  data = &SOURCEDS force ; 
run; 
   

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033V * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 *                  PARTY_UDF_DATE_VALUE -                A5DG55RP.BH0001BL * 
 *                   ecm_db.PARTY_UDF_DATE_VALUE                            * 
 * Target Table:    Join - work.W7KP837X                  A5DG55RP.BR0001ZR * 
 *==========================================================================*/ 


proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KP837X;
quit;

proc sql;
   create table work.W7KP837X as
   select
      PARTY_UDF_DATE_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_DATE_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_DATE_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_DATE_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_DATE_VALUE.UDF_VALUE length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_DATE_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_DATE_VALUE.PARTY_RK
      and W2288GWR.VALID_FROM_DTTM = PARTY_UDF_DATE_VALUE.VALID_FROM_DTTM
   ;
quit;

/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033Y * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W7KP837X                  A5DG55RP.BR0001ZR * 
 * Target Table:    PARTY_UDF_DATE_VALUE -                A5DG55RP.BH0001BL * 
 *                   ecm_db.PARTY_UDF_DATE_VALUE                            * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7KP837X); 
  
proc append base = ecm_db.PARTY_UDF_DATE_VALUE 
  data = &SOURCEDS force ; 
run; 
   

/*==========================================================================* 
 * Step:            Join                                  A5DG55RP.BV00033W * 
 * Transform:       Join                                                    * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Tables:   Lookup - work.W2288GWR                A5DG55RP.BR0001VT * 
 *                  PARTY_UDF_LGCHR_VALUE -               A5DG55RP.BH0001BN * 
 *                   ecm_db.PARTY_UDF_LGCHR_VALUE                           * 
 * Target Table:    Join - work.W7KP8R7V                  A5DG55RP.BR0001ZS * 
 *==========================================================================*/ 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W7KP8R7V;
quit;

proc sql;
   create table work.W7KP8R7V as
   select
      PARTY_UDF_LGCHR_VALUE.PARTY_RK length = 8   
         format = 11.
         informat = 11.
         label = 'PARTY_RK',
      W2288GWR.VALID_FROM_DTTM length = 8   
         format = DATETIME27.6
         informat = DATETIME27.6
         label = 'VALID_FROM_DTTM',
      PARTY_UDF_LGCHR_VALUE.UDF_TABLE_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_TABLE_NM',
      PARTY_UDF_LGCHR_VALUE.UDF_NM length = 30   
         format = $30.
         informat = $30.
         label = 'UDF_NM',
      PARTY_UDF_LGCHR_VALUE.ROW_NO length = 8   
         format = 11.
         informat = 11.
         label = 'ROW_NO',
      PARTY_UDF_LGCHR_VALUE.UDF_VALUE length = 1024   
         format = $1024.
         informat = $1024.
         label = 'UDF_VALUE'
   from
      work.W2288GWR, 
      ecm_db.PARTY_UDF_LGCHR_VALUE
   where
      W2288GWR.PARTY_RK = PARTY_UDF_LGCHR_VALUE.PARTY_RK
      and W2288GWR.OLD_VALID_FROM_DTTM = PARTY_UDF_LGCHR_VALUE.VALID_FROM_DTTM
   ;
quit;


/*==========================================================================* 
 * Step:            Table Loader                          A5DG55RP.BV00033Z * 
 * Transform:       Table Loader (Version 2.1)                              * 
 * Description:                                                             * 
 *                                                                          * 
 * Source Table:    Join - work.W7KP8R7V                  A5DG55RP.BR0001ZS * 
 * Target Table:    PARTY_UDF_LGCHR_VALUE -               A5DG55RP.BH0001BN * 
 *                   ecm_db.PARTY_UDF_LGCHR_VALUE                           * 
 *==========================================================================*/ 

%let SOURCEDS = %nrquote(work.W7KP8R7V); 
   
proc append base = ecm_db.PARTY_UDF_LGCHR_VALUE 
  data = &SOURCEDS force ; 
run; 
  

%mend;
